{
 "cells": [
  {
   "cell_type": "markdown",
   "id": "employed-private",
   "metadata": {},
   "source": [
    "# Neural and Universal Ordinary Differential Equations: Part 02\n",
    "Following along from notes by [Chris Rackauckas](https://mitmath.github.io/18S096SciML/lecture3/diffeq_ml).\n",
    "\n",
    "In the previous notebook is documented how we can use a neural network to solve a parameter problem relating to an ODE -- we essentially trained a neural network on an ODE model, and attempted to find a best fit for the model parameters.\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "id": "seeing-inspector",
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "<script>\n",
       "// Immediately-invoked-function-expression to avoid global variables.\n",
       "(function() {\n",
       "    var warning_div = document.getElementById(\"webio-warning-1251510723916641380\");\n",
       "    var hide = function () {\n",
       "        var script = document.getElementById(\"webio-setup-13695634961432416730\");\n",
       "        var parent = script && script.parentElement;\n",
       "        var grandparent = parent && parent.parentElement;\n",
       "        if (grandparent) {\n",
       "            grandparent.style.display = \"none\";\n",
       "        }\n",
       "        warning_div.style.display = \"none\";\n",
       "    };\n",
       "    if (typeof Jupyter !== \"undefined\") {\n",
       "        console.log(\"WebIO detected Jupyter notebook environment.\");\n",
       "        // Jupyter notebook.\n",
       "        var extensions = (\n",
       "            Jupyter\n",
       "            && Jupyter.notebook.config.data\n",
       "            && Jupyter.notebook.config.data.load_extensions\n",
       "        );\n",
       "        if (extensions && extensions[\"webio-jupyter-notebook\"]) {\n",
       "            // Extension already loaded.\n",
       "            console.log(\"Jupyter WebIO nbextension detected; not loading ad-hoc.\");\n",
       "            hide();\n",
       "            return;\n",
       "        }\n",
       "    } else if (window.location.pathname.includes(\"/lab\")) {\n",
       "        // Guessing JupyterLa\n",
       "        console.log(\"Jupyter Lab detected; make sure the @webio/jupyter-lab-provider labextension is installed.\");\n",
       "        hide();\n",
       "        return;\n",
       "    }\n",
       "})();\n",
       "\n",
       "</script>\n",
       "<p\n",
       "    id=\"webio-warning-1251510723916641380\"\n",
       "    class=\"output_text output_stderr\"\n",
       "    style=\"padding: 1em; font-weight: bold;\"\n",
       ">\n",
       "    Unable to load WebIO. Please make sure WebIO works for your Jupyter client.\n",
       "    For troubleshooting, please see <a href=\"https://juliagizmos.github.io/WebIO.jl/latest/providers/ijulia/\">\n",
       "    the WebIO/IJulia documentation</a>.\n",
       "    <!-- TODO: link to installation docs. -->\n",
       "</p>\n"
      ],
      "text/plain": [
       "HTML{String}(\"<script>\\n// Immediately-invoked-function-expression to avoid global variables.\\n(function() {\\n    var warning_div = document.getElementById(\\\"webio-warning-1251510723916641380\\\");\\n    var hide = function () {\\n        var script = document.getElementById(\\\"webio-setup-13695634961432416730\\\");\\n        var parent = script && script.parentElement;\\n        var grandparent = parent && parent.parentElement;\\n        if (grandparent) {\\n            grandparent.style.display = \\\"none\\\";\\n        }\\n        warning_div.style.display = \\\"none\\\";\\n    };\\n    if (typeof Jupyter !== \\\"undefined\\\") {\\n        console.log(\\\"WebIO detected Jupyter notebook environment.\\\");\\n        // Jupyter notebook.\\n        var extensions = (\\n            Jupyter\\n            && Jupyter.notebook.config.data\\n            && Jupyter.notebook.config.data.load_extensions\\n        );\\n        if (extensions && extensions[\\\"webio-jupyter-notebook\\\"]) {\\n            // Extension already loaded.\\n            console.log(\\\"Jupyter WebIO nbextension detected; not loading ad-hoc.\\\");\\n            hide();\\n            return;\\n        }\\n    } else if (window.location.pathname.includes(\\\"/lab\\\")) {\\n        // Guessing JupyterLa\\n        console.log(\\\"Jupyter Lab detected; make sure the @webio/jupyter-lab-provider labextension is installed.\\\");\\n        hide();\\n        return;\\n    }\\n})();\\n\\n</script>\\n<p\\n    id=\\\"webio-warning-1251510723916641380\\\"\\n    class=\\\"output_text output_stderr\\\"\\n    style=\\\"padding: 1em; font-weight: bold;\\\"\\n>\\n    Unable to load WebIO. Please make sure WebIO works for your Jupyter client.\\n    For troubleshooting, please see <a href=\\\"https://juliagizmos.github.io/WebIO.jl/latest/providers/ijulia/\\\">\\n    the WebIO/IJulia documentation</a>.\\n    <!-- TODO: link to installation docs. -->\\n</p>\\n\")"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "using OrdinaryDiffEq, Flux, DiffEqFlux, Plots"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "lyric-entry",
   "metadata": {},
   "source": [
    "## Defining and Training Neural ODEs\n",
    "\n",
    "Defining a neural ODE is the same as defining a parameterized differential equation, except here the parameterized ODE is a NN. \n",
    "\n",
    "Consider the following example; we wish to match the following data:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "id": "involved-scanning",
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "2×30 Matrix{Float32}:\n",
       " 2.0  1.9465    1.74178  1.23837  0.577125  …  1.40688   1.37023   1.29215\n",
       " 0.0  0.798831  1.46473  1.80877  1.86465      0.451367  0.728692  0.972095"
      ]
     },
     "execution_count": 2,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "u0 = Float32[2.; 0.]\n",
    "datasize = 30\n",
    "tspan = (0.0f0, 1.5f0)\n",
    "\n",
    "function trueODE!(du, u, p, t)\n",
    "    true_A = [-0.1 2.0; -2.0 -0.1]\n",
    "    du .= ((u.^3)'true_A)'\n",
    "end\n",
    "\n",
    "t = range(tspan[1], tspan[2], length=datasize)\n",
    "prob = ODEProblem(trueODE!, u0, tspan)\n",
    "ode_data = Array(solve(prob, Tsit5(), saveat=t))"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "western-waterproof",
   "metadata": {},
   "source": [
    "Let us quickly visualise this data:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "id": "hawaiian-river",
   "metadata": {},
   "outputs": [
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n",
       "<svg xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"600\" height=\"400\" viewBox=\"0 0 2400 1600\">\n",
       "<defs>\n",
       "  <clipPath id=\"clip310\">\n",
       "    <rect x=\"0\" y=\"0\" width=\"2400\" height=\"1600\"/>\n",
       "  </clipPath>\n",
       "</defs>\n",
       "<path clip-path=\"url(#clip310)\" d=\"\n",
       "M0 1600 L2400 1600 L2400 0 L0 0  Z\n",
       "  \" fill=\"#ffffff\" fill-rule=\"evenodd\" fill-opacity=\"1\"/>\n",
       "<defs>\n",
       "  <clipPath id=\"clip311\">\n",
       "    <rect x=\"480\" y=\"0\" width=\"1681\" height=\"1600\"/>\n",
       "  </clipPath>\n",
       "</defs>\n",
       "<path clip-path=\"url(#clip310)\" d=\"\n",
       "M147.478 1486.45 L2352.76 1486.45 L2352.76 47.2441 L147.478 47.2441  Z\n",
       "  \" fill=\"#ffffff\" fill-rule=\"evenodd\" fill-opacity=\"1\"/>\n",
       "<defs>\n",
       "  <clipPath id=\"clip312\">\n",
       "    <rect x=\"147\" y=\"47\" width=\"2206\" height=\"1440\"/>\n",
       "  </clipPath>\n",
       "</defs>\n",
       "<polyline clip-path=\"url(#clip312)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  496.85,1486.45 496.85,47.2441 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip312)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  855.549,1486.45 855.549,47.2441 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip312)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  1214.25,1486.45 1214.25,47.2441 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip312)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  1572.95,1486.45 1572.95,47.2441 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip312)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  1931.64,1486.45 1931.64,47.2441 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip312)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  2290.34,1486.45 2290.34,47.2441 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip310)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  147.478,1486.45 2352.76,1486.45 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip310)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  496.85,1486.45 496.85,1467.55 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip310)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  855.549,1486.45 855.549,1467.55 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip310)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  1214.25,1486.45 1214.25,1467.55 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip310)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  1572.95,1486.45 1572.95,1467.55 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip310)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  1931.64,1486.45 1931.64,1467.55 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip310)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  2290.34,1486.45 2290.34,1467.55 \n",
       "  \"/>\n",
       "<path clip-path=\"url(#clip310)\" d=\"M487.128 1512.56 L505.484 1512.56 L505.484 1516.5 L491.41 1516.5 L491.41 1524.97 Q492.429 1524.62 493.447 1524.46 Q494.466 1524.27 495.484 1524.27 Q501.271 1524.27 504.651 1527.44 Q508.031 1530.62 508.031 1536.03 Q508.031 1541.61 504.558 1544.71 Q501.086 1547.79 494.767 1547.79 Q492.591 1547.79 490.322 1547.42 Q488.077 1547.05 485.67 1546.31 L485.67 1541.61 Q487.753 1542.74 489.975 1543.3 Q492.197 1543.86 494.674 1543.86 Q498.679 1543.86 501.017 1541.75 Q503.355 1539.64 503.355 1536.03 Q503.355 1532.42 501.017 1530.31 Q498.679 1528.21 494.674 1528.21 Q492.799 1528.21 490.924 1528.62 Q489.072 1529.04 487.128 1529.92 L487.128 1512.56 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip310)\" d=\"M830.236 1543.18 L837.875 1543.18 L837.875 1516.82 L829.565 1518.49 L829.565 1514.23 L837.829 1512.56 L842.505 1512.56 L842.505 1543.18 L850.144 1543.18 L850.144 1547.12 L830.236 1547.12 L830.236 1543.18 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip310)\" d=\"M869.588 1515.64 Q865.977 1515.64 864.148 1519.2 Q862.343 1522.75 862.343 1529.87 Q862.343 1536.98 864.148 1540.55 Q865.977 1544.09 869.588 1544.09 Q873.222 1544.09 875.028 1540.55 Q876.856 1536.98 876.856 1529.87 Q876.856 1522.75 875.028 1519.2 Q873.222 1515.64 869.588 1515.64 M869.588 1511.93 Q875.398 1511.93 878.454 1516.54 Q881.532 1521.12 881.532 1529.87 Q881.532 1538.6 878.454 1543.21 Q875.398 1547.79 869.588 1547.79 Q863.778 1547.79 860.699 1543.21 Q857.644 1538.6 857.644 1529.87 Q857.644 1521.12 860.699 1516.54 Q863.778 1511.93 869.588 1511.93 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip310)\" d=\"M1189.43 1543.18 L1197.07 1543.18 L1197.07 1516.82 L1188.76 1518.49 L1188.76 1514.23 L1197.02 1512.56 L1201.7 1512.56 L1201.7 1543.18 L1209.34 1543.18 L1209.34 1547.12 L1189.43 1547.12 L1189.43 1543.18 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip310)\" d=\"M1218.83 1512.56 L1237.19 1512.56 L1237.19 1516.5 L1223.11 1516.5 L1223.11 1524.97 Q1224.13 1524.62 1225.15 1524.46 Q1226.17 1524.27 1227.19 1524.27 Q1232.97 1524.27 1236.35 1527.44 Q1239.73 1530.62 1239.73 1536.03 Q1239.73 1541.61 1236.26 1544.71 Q1232.79 1547.79 1226.47 1547.79 Q1224.29 1547.79 1222.02 1547.42 Q1219.78 1547.05 1217.37 1546.31 L1217.37 1541.61 Q1219.46 1542.74 1221.68 1543.3 Q1223.9 1543.86 1226.38 1543.86 Q1230.38 1543.86 1232.72 1541.75 Q1235.06 1539.64 1235.06 1536.03 Q1235.06 1532.42 1232.72 1530.31 Q1230.38 1528.21 1226.38 1528.21 Q1224.5 1528.21 1222.63 1528.62 Q1220.77 1529.04 1218.83 1529.92 L1218.83 1512.56 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip310)\" d=\"M1551.72 1543.18 L1568.04 1543.18 L1568.04 1547.12 L1546.09 1547.12 L1546.09 1543.18 Q1548.76 1540.43 1553.34 1535.8 Q1557.95 1531.15 1559.13 1529.81 Q1561.37 1527.28 1562.25 1525.55 Q1563.15 1523.79 1563.15 1522.1 Q1563.15 1519.34 1561.21 1517.61 Q1559.29 1515.87 1556.19 1515.87 Q1553.99 1515.87 1551.53 1516.63 Q1549.1 1517.4 1546.33 1518.95 L1546.33 1514.23 Q1549.15 1513.09 1551.6 1512.51 Q1554.06 1511.93 1556.09 1511.93 Q1561.46 1511.93 1564.66 1514.62 Q1567.85 1517.31 1567.85 1521.8 Q1567.85 1523.93 1567.04 1525.85 Q1566.26 1527.74 1564.15 1530.34 Q1563.57 1531.01 1560.47 1534.23 Q1557.37 1537.42 1551.72 1543.18 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip310)\" d=\"M1587.85 1515.64 Q1584.24 1515.64 1582.41 1519.2 Q1580.61 1522.75 1580.61 1529.87 Q1580.61 1536.98 1582.41 1540.55 Q1584.24 1544.09 1587.85 1544.09 Q1591.49 1544.09 1593.29 1540.55 Q1595.12 1536.98 1595.12 1529.87 Q1595.12 1522.75 1593.29 1519.2 Q1591.49 1515.64 1587.85 1515.64 M1587.85 1511.93 Q1593.66 1511.93 1596.72 1516.54 Q1599.8 1521.12 1599.8 1529.87 Q1599.8 1538.6 1596.72 1543.21 Q1593.66 1547.79 1587.85 1547.79 Q1582.04 1547.79 1578.96 1543.21 Q1575.91 1538.6 1575.91 1529.87 Q1575.91 1521.12 1578.96 1516.54 Q1582.04 1511.93 1587.85 1511.93 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip310)\" d=\"M1910.91 1543.18 L1927.23 1543.18 L1927.23 1547.12 L1905.29 1547.12 L1905.29 1543.18 Q1907.95 1540.43 1912.54 1535.8 Q1917.14 1531.15 1918.32 1529.81 Q1920.57 1527.28 1921.45 1525.55 Q1922.35 1523.79 1922.35 1522.1 Q1922.35 1519.34 1920.41 1517.61 Q1918.48 1515.87 1915.38 1515.87 Q1913.18 1515.87 1910.73 1516.63 Q1908.3 1517.4 1905.52 1518.95 L1905.52 1514.23 Q1908.35 1513.09 1910.8 1512.51 Q1913.25 1511.93 1915.29 1511.93 Q1920.66 1511.93 1923.85 1514.62 Q1927.05 1517.31 1927.05 1521.8 Q1927.05 1523.93 1926.24 1525.85 Q1925.45 1527.74 1923.35 1530.34 Q1922.77 1531.01 1919.66 1534.23 Q1916.56 1537.42 1910.91 1543.18 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip310)\" d=\"M1937.1 1512.56 L1955.45 1512.56 L1955.45 1516.5 L1941.38 1516.5 L1941.38 1524.97 Q1942.4 1524.62 1943.41 1524.46 Q1944.43 1524.27 1945.45 1524.27 Q1951.24 1524.27 1954.62 1527.44 Q1958 1530.62 1958 1536.03 Q1958 1541.61 1954.53 1544.71 Q1951.05 1547.79 1944.73 1547.79 Q1942.56 1547.79 1940.29 1547.42 Q1938.04 1547.05 1935.64 1546.31 L1935.64 1541.61 Q1937.72 1542.74 1939.94 1543.3 Q1942.16 1543.86 1944.64 1543.86 Q1948.65 1543.86 1950.98 1541.75 Q1953.32 1539.64 1953.32 1536.03 Q1953.32 1532.42 1950.98 1530.31 Q1948.65 1528.21 1944.64 1528.21 Q1942.77 1528.21 1940.89 1528.62 Q1939.04 1529.04 1937.1 1529.92 L1937.1 1512.56 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip310)\" d=\"M2279.19 1528.49 Q2282.54 1529.2 2284.42 1531.47 Q2286.31 1533.74 2286.31 1537.07 Q2286.31 1542.19 2282.8 1544.99 Q2279.28 1547.79 2272.8 1547.79 Q2270.62 1547.79 2268.31 1547.35 Q2266.01 1546.93 2263.56 1546.08 L2263.56 1541.56 Q2265.5 1542.7 2267.82 1543.28 Q2270.13 1543.86 2272.66 1543.86 Q2277.06 1543.86 2279.35 1542.12 Q2281.66 1540.38 2281.66 1537.07 Q2281.66 1534.02 2279.51 1532.31 Q2277.38 1530.57 2273.56 1530.57 L2269.53 1530.57 L2269.53 1526.73 L2273.75 1526.73 Q2277.19 1526.73 2279.02 1525.36 Q2280.85 1523.97 2280.85 1521.38 Q2280.85 1518.72 2278.95 1517.31 Q2277.08 1515.87 2273.56 1515.87 Q2271.64 1515.87 2269.44 1516.29 Q2267.24 1516.7 2264.6 1517.58 L2264.6 1513.42 Q2267.26 1512.68 2269.58 1512.31 Q2271.92 1511.93 2273.98 1511.93 Q2279.3 1511.93 2282.4 1514.37 Q2285.5 1516.77 2285.5 1520.89 Q2285.5 1523.76 2283.86 1525.75 Q2282.22 1527.72 2279.19 1528.49 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip310)\" d=\"M2305.18 1515.64 Q2301.57 1515.64 2299.74 1519.2 Q2297.93 1522.75 2297.93 1529.87 Q2297.93 1536.98 2299.74 1540.55 Q2301.57 1544.09 2305.18 1544.09 Q2308.81 1544.09 2310.62 1540.55 Q2312.45 1536.98 2312.45 1529.87 Q2312.45 1522.75 2310.62 1519.2 Q2308.81 1515.64 2305.18 1515.64 M2305.18 1511.93 Q2310.99 1511.93 2314.05 1516.54 Q2317.12 1521.12 2317.12 1529.87 Q2317.12 1538.6 2314.05 1543.21 Q2310.99 1547.79 2305.18 1547.79 Q2299.37 1547.79 2296.29 1543.21 Q2293.24 1538.6 2293.24 1529.87 Q2293.24 1521.12 2296.29 1516.54 Q2299.37 1511.93 2305.18 1511.93 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><polyline clip-path=\"url(#clip312)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  147.478,1185.84 2352.76,1185.84 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip312)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  147.478,819.885 2352.76,819.885 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip312)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  147.478,453.931 2352.76,453.931 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip312)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  147.478,87.9763 2352.76,87.9763 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip310)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  147.478,1486.45 147.478,47.2441 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip310)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  147.478,1185.84 166.376,1185.84 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip310)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  147.478,819.885 166.376,819.885 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip310)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  147.478,453.931 166.376,453.931 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip310)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  147.478,87.9763 166.376,87.9763 \n",
       "  \"/>\n",
       "<path clip-path=\"url(#clip310)\" d=\"M50.9921 1186.29 L80.6679 1186.29 L80.6679 1190.23 L50.9921 1190.23 L50.9921 1186.29 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip310)\" d=\"M91.5706 1199.18 L99.2095 1199.18 L99.2095 1172.82 L90.8993 1174.49 L90.8993 1170.23 L99.1632 1168.56 L103.839 1168.56 L103.839 1199.18 L111.478 1199.18 L111.478 1203.12 L91.5706 1203.12 L91.5706 1199.18 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip310)\" d=\"M99.5335 805.684 Q95.9224 805.684 94.0937 809.248 Q92.2882 812.79 92.2882 819.92 Q92.2882 827.026 94.0937 830.591 Q95.9224 834.133 99.5335 834.133 Q103.168 834.133 104.973 830.591 Q106.802 827.026 106.802 819.92 Q106.802 812.79 104.973 809.248 Q103.168 805.684 99.5335 805.684 M99.5335 801.98 Q105.344 801.98 108.399 806.586 Q111.478 811.17 111.478 819.92 Q111.478 828.647 108.399 833.253 Q105.344 837.836 99.5335 837.836 Q93.7234 837.836 90.6447 833.253 Q87.5892 828.647 87.5892 819.92 Q87.5892 811.17 90.6447 806.586 Q93.7234 801.98 99.5335 801.98 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip310)\" d=\"M91.5706 467.275 L99.2095 467.275 L99.2095 440.91 L90.8993 442.577 L90.8993 438.317 L99.1632 436.651 L103.839 436.651 L103.839 467.275 L111.478 467.275 L111.478 471.211 L91.5706 471.211 L91.5706 467.275 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip310)\" d=\"M95.1586 101.321 L111.478 101.321 L111.478 105.256 L89.5336 105.256 L89.5336 101.321 Q92.1956 98.5665 96.7789 93.9369 Q101.385 89.2841 102.566 87.9416 Q104.811 85.4184 105.691 83.6823 Q106.594 81.9231 106.594 80.2333 Q106.594 77.4786 104.649 75.7425 Q102.728 74.0064 99.6261 74.0064 Q97.4271 74.0064 94.9734 74.7703 Q92.5428 75.5342 89.7651 77.0851 L89.7651 72.3629 Q92.5891 71.2287 95.0428 70.65 Q97.4965 70.0713 99.5335 70.0713 Q104.904 70.0713 108.098 72.7565 Q111.293 75.4416 111.293 79.9323 Q111.293 82.062 110.483 83.9832 Q109.696 85.8814 107.589 88.474 Q107.01 89.1453 103.909 92.3628 Q100.807 95.5573 95.1586 101.321 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><polyline clip-path=\"url(#clip312)\" style=\"stroke:#009af9; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  209.891,87.9763 281.631,107.554 353.371,182.473 425.111,366.698 496.85,608.684 568.59,849.126 640.33,1076.46 712.069,1274.71 783.809,1402.14 855.549,1445.72 \n",
       "  927.288,1445.21 999.028,1436.17 1070.77,1423.54 1142.51,1388.1 1214.25,1305.9 1285.99,1178.84 1357.73,1031.28 1429.47,883.342 1501.21,740.538 1572.95,603.759 \n",
       "  1644.69,478.86 1716.42,379.414 1788.16,317.748 1859.9,292.031 1931.64,288.372 2003.38,292.792 2075.12,298.341 2146.86,305.031 2218.6,318.443 2290.34,347.018 \n",
       "  \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip312)\" style=\"stroke:#e26f46; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  209.891,819.885 281.631,527.549 353.371,283.86 425.111,157.957 496.85,137.507 568.59,147.957 640.33,163.084 712.069,211.672 783.809,332.426 855.549,510.356 \n",
       "  927.288,701.529 999.028,886.387 1070.77,1062.23 1142.51,1218.8 1214.25,1331.67 1285.99,1386.13 1357.73,1397.97 1429.47,1393.15 1501.21,1385.99 1572.95,1376.07 \n",
       "  1644.69,1352.09 1716.42,1299.17 1788.16,1212.94 1859.9,1104.54 1931.64,988.421 2003.38,873.611 2075.12,762.292 2146.86,654.705 2218.6,553.217 2290.34,464.143 \n",
       "  \n",
       "  \"/>\n",
       "<path clip-path=\"url(#clip310)\" d=\"\n",
       "M1981.79 250.738 L2279.25 250.738 L2279.25 95.2176 L1981.79 95.2176  Z\n",
       "  \" fill=\"#ffffff\" fill-rule=\"evenodd\" fill-opacity=\"1\"/>\n",
       "<polyline clip-path=\"url(#clip310)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  1981.79,250.738 2279.25,250.738 2279.25,95.2176 1981.79,95.2176 1981.79,250.738 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip310)\" style=\"stroke:#009af9; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  2006.29,147.058 2153.31,147.058 \n",
       "  \"/>\n",
       "<path clip-path=\"url(#clip310)\" d=\"M2191.65 166.745 Q2189.85 171.375 2188.13 172.787 Q2186.42 174.199 2183.55 174.199 L2180.15 174.199 L2180.15 170.634 L2182.65 170.634 Q2184.41 170.634 2185.38 169.8 Q2186.35 168.967 2187.53 165.865 L2188.3 163.921 L2177.81 138.412 L2182.32 138.412 L2190.43 158.689 L2198.53 138.412 L2203.04 138.412 L2191.65 166.745 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip310)\" d=\"M2210.33 160.402 L2217.97 160.402 L2217.97 134.037 L2209.66 135.703 L2209.66 131.444 L2217.93 129.778 L2222.6 129.778 L2222.6 160.402 L2230.24 160.402 L2230.24 164.338 L2210.33 164.338 L2210.33 160.402 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><polyline clip-path=\"url(#clip310)\" style=\"stroke:#e26f46; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  2006.29,198.898 2153.31,198.898 \n",
       "  \"/>\n",
       "<path clip-path=\"url(#clip310)\" d=\"M2191.65 218.585 Q2189.85 223.215 2188.13 224.627 Q2186.42 226.039 2183.55 226.039 L2180.15 226.039 L2180.15 222.474 L2182.65 222.474 Q2184.41 222.474 2185.38 221.64 Q2186.35 220.807 2187.53 217.705 L2188.3 215.761 L2177.81 190.252 L2182.32 190.252 L2190.43 210.529 L2198.53 190.252 L2203.04 190.252 L2191.65 218.585 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip310)\" d=\"M2213.55 212.242 L2229.87 212.242 L2229.87 216.178 L2207.93 216.178 L2207.93 212.242 Q2210.59 209.488 2215.17 204.858 Q2219.78 200.205 2220.96 198.863 Q2223.2 196.34 2224.08 194.604 Q2224.99 192.844 2224.99 191.155 Q2224.99 188.4 2223.04 186.664 Q2221.12 184.928 2218.02 184.928 Q2215.82 184.928 2213.37 185.692 Q2210.94 186.455 2208.16 188.006 L2208.16 183.284 Q2210.98 182.15 2213.43 181.571 Q2215.89 180.993 2217.93 180.993 Q2223.3 180.993 2226.49 183.678 Q2229.68 186.363 2229.68 190.854 Q2229.68 192.983 2228.87 194.905 Q2228.09 196.803 2225.98 199.395 Q2225.4 200.067 2222.3 203.284 Q2219.2 206.479 2213.55 212.242 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /></svg>\n"
      ]
     },
     "execution_count": 3,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "plot(ode_data')"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "analyzed-platform",
   "metadata": {},
   "source": [
    "We will use a so-called *knowledge-infused approach*; that is to say, we assume that we knew the ODE had cubic behaviour. We can attempt to encode that physical information into a dense NN as:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "id": "incorporate-friendly",
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "Chain(\n",
       "  var\"#1#2\"(),\n",
       "  Dense(2, 50, tanh),                   \u001b[90m# 150 parameters\u001b[39m\n",
       "  Dense(50, 2),                         \u001b[90m# 102 parameters\u001b[39m\n",
       ")\u001b[90m                   # Total: 4 arrays, \u001b[39m252 parameters, 1.234 KiB."
      ]
     },
     "execution_count": 4,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "# build a NN\n",
    "dudt = Chain(\n",
    "    x -> x.^3,\n",
    "    Dense(2, 50, tanh),\n",
    "    Dense(50, 2)\n",
    ")"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "advised-plaza",
   "metadata": {},
   "source": [
    "To train this network we will make use of `Flux.destructure` and `Flux.restructure`, allowing us to take the parameters out of a NN into a vector, and similarly rebuild a NN from a parameter vector. \n",
    "\n",
    "Using these, we define the ODE:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "id": "parental-shower",
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "\u001b[36mODEProblem\u001b[0m with uType \u001b[36mVector{Float32}\u001b[0m and tType \u001b[36mFloat32\u001b[0m. In-place: \u001b[36mfalse\u001b[0m\n",
       "timespan: (0.0f0, 1.5f0)\n",
       "u0: 2-element Vector{Float32}:\n",
       " 2.0\n",
       " 0.0"
      ]
     },
     "execution_count": 5,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "p, re = Flux.destructure(dudt)\n",
    "dudt2_(u, p, t) = re(p)(u)\n",
    "prob2 = ODEProblem(dudt2_, u0, tspan, p)"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "enabling-disaster",
   "metadata": {},
   "source": [
    "This is equivalent to\n",
    "\n",
    "$$u^\\prime = \\text{NN}(u)$$\n",
    "\n",
    "where the parameters are the parameters of the NN. We then use the same structure as before to train the network to reconstruct the ODE:\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 6,
   "id": "actual-exemption",
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "loss_n_ode() = 10.00524f0\n",
      "loss_n_ode() = 2.0725229f0\n",
      "loss_n_ode() = 0.83961827f0\n",
      "loss_n_ode() = 0.5685626f0\n",
      "loss_n_ode() = 0.38171425f0\n",
      "loss_n_ode() = 0.19634308f0\n"
     ]
    },
    {
     "data": {
      "text/plain": [
       "\"Done\""
      ]
     },
     "execution_count": 6,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "function predict_n_ode()\n",
    "    Array(concrete_solve(prob2, Tsit5(), u0, p, saveat=t))\n",
    "end\n",
    "\n",
    "loss_n_ode() = sum(abs2, ode_data .- predict_n_ode())\n",
    "\n",
    "\n",
    "data = Iterators.repeated((), 300)\n",
    "opt = ADAM(0.1)\n",
    "\n",
    "training_plots = []\n",
    "iter = 0\n",
    "\n",
    "callback = function()\n",
    "    global iter += 1\n",
    "    if iter % 50 == 0\n",
    "        @show loss_n_ode()\n",
    "\n",
    "        cur_pred = predict_n_ode()\n",
    "        pl = Plots.scatter(t, ode_data[1,:], label=\"data\")\n",
    "        Plots.scatter!(pl, t, cur_pred[1,:], label=\"prediction\")\n",
    "        push!(training_plots, plot(pl))\n",
    "    end\n",
    "end\n",
    "\n",
    "ps = Flux.params(p)\n",
    "Flux.train!(loss_n_ode, ps, data, opt, cb=callback)\n",
    "\"Done\""
   ]
  },
  {
   "cell_type": "markdown",
   "id": "executive-concord",
   "metadata": {},
   "source": [
    "We can then view our plots:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 7,
   "id": "complicated-disco",
   "metadata": {},
   "outputs": [
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n",
       "<svg xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"600\" height=\"400\" viewBox=\"0 0 2400 1600\">\n",
       "<defs>\n",
       "  <clipPath id=\"clip350\">\n",
       "    <rect x=\"0\" y=\"0\" width=\"2400\" height=\"1600\"/>\n",
       "  </clipPath>\n",
       "</defs>\n",
       "<path clip-path=\"url(#clip350)\" d=\"\n",
       "M0 1600 L2400 1600 L2400 0 L0 0  Z\n",
       "  \" fill=\"#ffffff\" fill-rule=\"evenodd\" fill-opacity=\"1\"/>\n",
       "<defs>\n",
       "  <clipPath id=\"clip351\">\n",
       "    <rect x=\"480\" y=\"0\" width=\"1681\" height=\"1600\"/>\n",
       "  </clipPath>\n",
       "</defs>\n",
       "<path clip-path=\"url(#clip350)\" d=\"\n",
       "M147.478 686.448 L752.756 686.448 L752.756 47.2441 L147.478 47.2441  Z\n",
       "  \" fill=\"#ffffff\" fill-rule=\"evenodd\" fill-opacity=\"1\"/>\n",
       "<defs>\n",
       "  <clipPath id=\"clip352\">\n",
       "    <rect x=\"147\" y=\"47\" width=\"606\" height=\"640\"/>\n",
       "  </clipPath>\n",
       "</defs>\n",
       "<polyline clip-path=\"url(#clip352)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  164.608,686.448 164.608,47.2441 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip352)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  354.947,686.448 354.947,47.2441 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip352)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  545.286,686.448 545.286,47.2441 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip352)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  735.625,686.448 735.625,47.2441 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  147.478,686.448 752.756,686.448 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  164.608,686.448 164.608,667.55 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  354.947,686.448 354.947,667.55 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  545.286,686.448 545.286,667.55 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  735.625,686.448 735.625,667.55 \n",
       "  \"/>\n",
       "<path clip-path=\"url(#clip350)\" d=\"M141.993 715.639 Q138.382 715.639 136.553 719.203 Q134.747 722.745 134.747 729.875 Q134.747 736.981 136.553 740.546 Q138.382 744.087 141.993 744.087 Q145.627 744.087 147.433 740.546 Q149.261 736.981 149.261 729.875 Q149.261 722.745 147.433 719.203 Q145.627 715.639 141.993 715.639 M141.993 711.935 Q147.803 711.935 150.858 716.541 Q153.937 721.125 153.937 729.875 Q153.937 738.601 150.858 743.208 Q147.803 747.791 141.993 747.791 Q136.183 747.791 133.104 743.208 Q130.048 738.601 130.048 729.875 Q130.048 721.125 133.104 716.541 Q136.183 711.935 141.993 711.935 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M162.155 741.24 L167.039 741.24 L167.039 747.12 L162.155 747.12 L162.155 741.24 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M187.224 715.639 Q183.613 715.639 181.784 719.203 Q179.979 722.745 179.979 729.875 Q179.979 736.981 181.784 740.546 Q183.613 744.087 187.224 744.087 Q190.858 744.087 192.664 740.546 Q194.493 736.981 194.493 729.875 Q194.493 722.745 192.664 719.203 Q190.858 715.639 187.224 715.639 M187.224 711.935 Q193.034 711.935 196.09 716.541 Q199.168 721.125 199.168 729.875 Q199.168 738.601 196.09 743.208 Q193.034 747.791 187.224 747.791 Q181.414 747.791 178.335 743.208 Q175.28 738.601 175.28 729.875 Q175.28 721.125 178.335 716.541 Q181.414 711.935 187.224 711.935 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M332.829 715.639 Q329.218 715.639 327.39 719.203 Q325.584 722.745 325.584 729.875 Q325.584 736.981 327.39 740.546 Q329.218 744.087 332.829 744.087 Q336.464 744.087 338.269 740.546 Q340.098 736.981 340.098 729.875 Q340.098 722.745 338.269 719.203 Q336.464 715.639 332.829 715.639 M332.829 711.935 Q338.64 711.935 341.695 716.541 Q344.774 721.125 344.774 729.875 Q344.774 738.601 341.695 743.208 Q338.64 747.791 332.829 747.791 Q327.019 747.791 323.941 743.208 Q320.885 738.601 320.885 729.875 Q320.885 721.125 323.941 716.541 Q327.019 711.935 332.829 711.935 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M352.991 741.24 L357.876 741.24 L357.876 747.12 L352.991 747.12 L352.991 741.24 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M368.107 712.56 L386.463 712.56 L386.463 716.495 L372.389 716.495 L372.389 724.967 Q373.408 724.62 374.426 724.458 Q375.445 724.273 376.464 724.273 Q382.251 724.273 385.63 727.444 Q389.01 730.615 389.01 736.032 Q389.01 741.611 385.538 744.712 Q382.065 747.791 375.746 747.791 Q373.57 747.791 371.301 747.421 Q369.056 747.05 366.649 746.31 L366.649 741.611 Q368.732 742.745 370.954 743.3 Q373.176 743.856 375.653 743.856 Q379.658 743.856 381.996 741.75 Q384.334 739.643 384.334 736.032 Q384.334 732.421 381.996 730.314 Q379.658 728.208 375.653 728.208 Q373.778 728.208 371.903 728.625 Q370.051 729.041 368.107 729.921 L368.107 712.56 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M512.439 743.185 L520.078 743.185 L520.078 716.819 L511.768 718.486 L511.768 714.227 L520.032 712.56 L524.708 712.56 L524.708 743.185 L532.347 743.185 L532.347 747.12 L512.439 747.12 L512.439 743.185 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M541.791 741.24 L546.675 741.24 L546.675 747.12 L541.791 747.12 L541.791 741.24 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M566.86 715.639 Q563.249 715.639 561.421 719.203 Q559.615 722.745 559.615 729.875 Q559.615 736.981 561.421 740.546 Q563.249 744.087 566.86 744.087 Q570.495 744.087 572.3 740.546 Q574.129 736.981 574.129 729.875 Q574.129 722.745 572.3 719.203 Q570.495 715.639 566.86 715.639 M566.86 711.935 Q572.671 711.935 575.726 716.541 Q578.805 721.125 578.805 729.875 Q578.805 738.601 575.726 743.208 Q572.671 747.791 566.86 747.791 Q561.05 747.791 557.972 743.208 Q554.916 738.601 554.916 729.875 Q554.916 721.125 557.972 716.541 Q561.05 711.935 566.86 711.935 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M703.276 743.185 L710.915 743.185 L710.915 716.819 L702.605 718.486 L702.605 714.227 L710.869 712.56 L715.544 712.56 L715.544 743.185 L723.183 743.185 L723.183 747.12 L703.276 747.12 L703.276 743.185 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M732.628 741.24 L737.512 741.24 L737.512 747.12 L732.628 747.12 L732.628 741.24 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M747.743 712.56 L766.1 712.56 L766.1 716.495 L752.026 716.495 L752.026 724.967 Q753.044 724.62 754.063 724.458 Q755.081 724.273 756.1 724.273 Q761.887 724.273 765.266 727.444 Q768.646 730.615 768.646 736.032 Q768.646 741.611 765.174 744.712 Q761.702 747.791 755.382 747.791 Q753.206 747.791 750.938 747.421 Q748.692 747.05 746.285 746.31 L746.285 741.611 Q748.368 742.745 750.591 743.3 Q752.813 743.856 755.29 743.856 Q759.294 743.856 761.632 741.75 Q763.97 739.643 763.97 736.032 Q763.97 732.421 761.632 730.314 Q759.294 728.208 755.29 728.208 Q753.415 728.208 751.54 728.625 Q749.688 729.041 747.743 729.921 L747.743 712.56 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><polyline clip-path=\"url(#clip352)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  147.478,552.936 752.756,552.936 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip352)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  147.478,390.403 752.756,390.403 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip352)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  147.478,227.869 752.756,227.869 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip352)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  147.478,65.3348 752.756,65.3348 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  147.478,686.448 147.478,47.2441 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  147.478,552.936 166.376,552.936 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  147.478,390.403 166.376,390.403 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  147.478,227.869 166.376,227.869 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  147.478,65.3348 166.376,65.3348 \n",
       "  \"/>\n",
       "<path clip-path=\"url(#clip350)\" d=\"M50.9921 553.388 L80.6679 553.388 L80.6679 557.323 L50.9921 557.323 L50.9921 553.388 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M91.5706 566.281 L99.2095 566.281 L99.2095 539.916 L90.8993 541.582 L90.8993 537.323 L99.1632 535.656 L103.839 535.656 L103.839 566.281 L111.478 566.281 L111.478 570.216 L91.5706 570.216 L91.5706 566.281 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M99.5335 376.201 Q95.9224 376.201 94.0937 379.766 Q92.2882 383.308 92.2882 390.437 Q92.2882 397.544 94.0937 401.109 Q95.9224 404.65 99.5335 404.65 Q103.168 404.65 104.973 401.109 Q106.802 397.544 106.802 390.437 Q106.802 383.308 104.973 379.766 Q103.168 376.201 99.5335 376.201 M99.5335 372.498 Q105.344 372.498 108.399 377.104 Q111.478 381.687 111.478 390.437 Q111.478 399.164 108.399 403.771 Q105.344 408.354 99.5335 408.354 Q93.7234 408.354 90.6447 403.771 Q87.5892 399.164 87.5892 390.437 Q87.5892 381.687 90.6447 377.104 Q93.7234 372.498 99.5335 372.498 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M91.5706 241.214 L99.2095 241.214 L99.2095 214.848 L90.8993 216.515 L90.8993 212.255 L99.1632 210.589 L103.839 210.589 L103.839 241.214 L111.478 241.214 L111.478 245.149 L91.5706 245.149 L91.5706 241.214 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M95.1586 78.6796 L111.478 78.6796 L111.478 82.6148 L89.5336 82.6148 L89.5336 78.6796 Q92.1956 75.925 96.7789 71.2954 Q101.385 66.6426 102.566 65.3 Q104.811 62.7769 105.691 61.0408 Q106.594 59.2816 106.594 57.5918 Q106.594 54.8371 104.649 53.101 Q102.728 51.3649 99.6261 51.3649 Q97.4271 51.3649 94.9734 52.1288 Q92.5428 52.8927 89.7651 54.4436 L89.7651 49.7214 Q92.5891 48.5872 95.0428 48.0085 Q97.4965 47.4298 99.5335 47.4298 Q104.904 47.4298 108.098 50.1149 Q111.293 52.8001 111.293 57.2908 Q111.293 59.4204 110.483 61.3417 Q109.696 63.2399 107.589 65.8325 Q107.01 66.5037 103.909 69.7213 Q100.807 72.9157 95.1586 78.6796 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><circle clip-path=\"url(#clip352)\" cx=\"164.608\" cy=\"65.3348\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"184.299\" cy=\"74.0299\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"203.989\" cy=\"107.304\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"223.679\" cy=\"189.125\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"243.369\" cy=\"296.6\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"263.06\" cy=\"403.389\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"282.75\" cy=\"504.355\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"302.44\" cy=\"592.409\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"322.13\" cy=\"649.003\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"341.821\" cy=\"668.357\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"361.511\" cy=\"668.133\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"381.201\" cy=\"664.117\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"400.891\" cy=\"658.507\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"420.582\" cy=\"642.767\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"440.272\" cy=\"606.259\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"459.962\" cy=\"549.827\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"479.652\" cy=\"484.289\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"499.343\" cy=\"418.586\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"519.033\" cy=\"355.162\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"538.723\" cy=\"294.413\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"558.413\" cy=\"238.941\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"578.103\" cy=\"194.773\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"597.794\" cy=\"167.385\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"617.484\" cy=\"155.963\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"637.174\" cy=\"154.338\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"656.864\" cy=\"156.301\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"676.555\" cy=\"158.766\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"696.245\" cy=\"161.737\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"715.935\" cy=\"167.693\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"735.625\" cy=\"180.385\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"164.608\" cy=\"65.3348\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"184.299\" cy=\"104.752\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"203.989\" cy=\"141.676\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"223.679\" cy=\"175.822\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"243.369\" cy=\"227.53\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"263.06\" cy=\"305.948\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"282.75\" cy=\"382.51\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"302.44\" cy=\"454.677\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"322.13\" cy=\"520.943\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"341.821\" cy=\"570.647\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"361.511\" cy=\"585.047\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"381.201\" cy=\"582.586\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"400.891\" cy=\"578.996\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"420.582\" cy=\"574.871\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"440.272\" cy=\"560.882\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"459.962\" cy=\"520.884\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"479.652\" cy=\"452.621\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"499.343\" cy=\"376.693\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"519.033\" cy=\"297.866\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"538.723\" cy=\"223.103\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"558.413\" cy=\"181.148\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"578.103\" cy=\"180.577\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"597.794\" cy=\"194.185\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"617.484\" cy=\"208.633\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"637.174\" cy=\"221.019\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"656.864\" cy=\"231.243\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"676.555\" cy=\"240.312\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"696.245\" cy=\"249.685\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"715.935\" cy=\"260.802\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip352)\" cx=\"735.625\" cy=\"274.401\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<path clip-path=\"url(#clip350)\" d=\"\n",
       "M947.478 686.448 L1552.76 686.448 L1552.76 47.2441 L947.478 47.2441  Z\n",
       "  \" fill=\"#ffffff\" fill-rule=\"evenodd\" fill-opacity=\"1\"/>\n",
       "<defs>\n",
       "  <clipPath id=\"clip353\">\n",
       "    <rect x=\"947\" y=\"47\" width=\"606\" height=\"640\"/>\n",
       "  </clipPath>\n",
       "</defs>\n",
       "<polyline clip-path=\"url(#clip353)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  964.608,686.448 964.608,47.2441 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip353)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  1154.95,686.448 1154.95,47.2441 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip353)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  1345.29,686.448 1345.29,47.2441 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip353)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  1535.63,686.448 1535.63,47.2441 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  947.478,686.448 1552.76,686.448 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  964.608,686.448 964.608,667.55 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  1154.95,686.448 1154.95,667.55 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  1345.29,686.448 1345.29,667.55 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  1535.63,686.448 1535.63,667.55 \n",
       "  \"/>\n",
       "<path clip-path=\"url(#clip350)\" d=\"M941.993 715.639 Q938.382 715.639 936.553 719.203 Q934.747 722.745 934.747 729.875 Q934.747 736.981 936.553 740.546 Q938.382 744.087 941.993 744.087 Q945.627 744.087 947.433 740.546 Q949.261 736.981 949.261 729.875 Q949.261 722.745 947.433 719.203 Q945.627 715.639 941.993 715.639 M941.993 711.935 Q947.803 711.935 950.858 716.541 Q953.937 721.125 953.937 729.875 Q953.937 738.601 950.858 743.208 Q947.803 747.791 941.993 747.791 Q936.183 747.791 933.104 743.208 Q930.048 738.601 930.048 729.875 Q930.048 721.125 933.104 716.541 Q936.183 711.935 941.993 711.935 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M962.155 741.24 L967.039 741.24 L967.039 747.12 L962.155 747.12 L962.155 741.24 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M987.224 715.639 Q983.613 715.639 981.784 719.203 Q979.979 722.745 979.979 729.875 Q979.979 736.981 981.784 740.546 Q983.613 744.087 987.224 744.087 Q990.858 744.087 992.664 740.546 Q994.493 736.981 994.493 729.875 Q994.493 722.745 992.664 719.203 Q990.858 715.639 987.224 715.639 M987.224 711.935 Q993.034 711.935 996.09 716.541 Q999.168 721.125 999.168 729.875 Q999.168 738.601 996.09 743.208 Q993.034 747.791 987.224 747.791 Q981.414 747.791 978.335 743.208 Q975.28 738.601 975.28 729.875 Q975.28 721.125 978.335 716.541 Q981.414 711.935 987.224 711.935 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M1132.83 715.639 Q1129.22 715.639 1127.39 719.203 Q1125.58 722.745 1125.58 729.875 Q1125.58 736.981 1127.39 740.546 Q1129.22 744.087 1132.83 744.087 Q1136.46 744.087 1138.27 740.546 Q1140.1 736.981 1140.1 729.875 Q1140.1 722.745 1138.27 719.203 Q1136.46 715.639 1132.83 715.639 M1132.83 711.935 Q1138.64 711.935 1141.7 716.541 Q1144.77 721.125 1144.77 729.875 Q1144.77 738.601 1141.7 743.208 Q1138.64 747.791 1132.83 747.791 Q1127.02 747.791 1123.94 743.208 Q1120.89 738.601 1120.89 729.875 Q1120.89 721.125 1123.94 716.541 Q1127.02 711.935 1132.83 711.935 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M1152.99 741.24 L1157.88 741.24 L1157.88 747.12 L1152.99 747.12 L1152.99 741.24 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M1168.11 712.56 L1186.46 712.56 L1186.46 716.495 L1172.39 716.495 L1172.39 724.967 Q1173.41 724.62 1174.43 724.458 Q1175.44 724.273 1176.46 724.273 Q1182.25 724.273 1185.63 727.444 Q1189.01 730.615 1189.01 736.032 Q1189.01 741.611 1185.54 744.712 Q1182.07 747.791 1175.75 747.791 Q1173.57 747.791 1171.3 747.421 Q1169.06 747.05 1166.65 746.31 L1166.65 741.611 Q1168.73 742.745 1170.95 743.3 Q1173.18 743.856 1175.65 743.856 Q1179.66 743.856 1182 741.75 Q1184.33 739.643 1184.33 736.032 Q1184.33 732.421 1182 730.314 Q1179.66 728.208 1175.65 728.208 Q1173.78 728.208 1171.9 728.625 Q1170.05 729.041 1168.11 729.921 L1168.11 712.56 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M1312.44 743.185 L1320.08 743.185 L1320.08 716.819 L1311.77 718.486 L1311.77 714.227 L1320.03 712.56 L1324.71 712.56 L1324.71 743.185 L1332.35 743.185 L1332.35 747.12 L1312.44 747.12 L1312.44 743.185 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M1341.79 741.24 L1346.68 741.24 L1346.68 747.12 L1341.79 747.12 L1341.79 741.24 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M1366.86 715.639 Q1363.25 715.639 1361.42 719.203 Q1359.62 722.745 1359.62 729.875 Q1359.62 736.981 1361.42 740.546 Q1363.25 744.087 1366.86 744.087 Q1370.49 744.087 1372.3 740.546 Q1374.13 736.981 1374.13 729.875 Q1374.13 722.745 1372.3 719.203 Q1370.49 715.639 1366.86 715.639 M1366.86 711.935 Q1372.67 711.935 1375.73 716.541 Q1378.8 721.125 1378.8 729.875 Q1378.8 738.601 1375.73 743.208 Q1372.67 747.791 1366.86 747.791 Q1361.05 747.791 1357.97 743.208 Q1354.92 738.601 1354.92 729.875 Q1354.92 721.125 1357.97 716.541 Q1361.05 711.935 1366.86 711.935 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M1503.28 743.185 L1510.91 743.185 L1510.91 716.819 L1502.6 718.486 L1502.6 714.227 L1510.87 712.56 L1515.54 712.56 L1515.54 743.185 L1523.18 743.185 L1523.18 747.12 L1503.28 747.12 L1503.28 743.185 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M1532.63 741.24 L1537.51 741.24 L1537.51 747.12 L1532.63 747.12 L1532.63 741.24 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M1547.74 712.56 L1566.1 712.56 L1566.1 716.495 L1552.03 716.495 L1552.03 724.967 Q1553.04 724.62 1554.06 724.458 Q1555.08 724.273 1556.1 724.273 Q1561.89 724.273 1565.27 727.444 Q1568.65 730.615 1568.65 736.032 Q1568.65 741.611 1565.17 744.712 Q1561.7 747.791 1555.38 747.791 Q1553.21 747.791 1550.94 747.421 Q1548.69 747.05 1546.29 746.31 L1546.29 741.611 Q1548.37 742.745 1550.59 743.3 Q1552.81 743.856 1555.29 743.856 Q1559.29 743.856 1561.63 741.75 Q1563.97 739.643 1563.97 736.032 Q1563.97 732.421 1561.63 730.314 Q1559.29 728.208 1555.29 728.208 Q1553.41 728.208 1551.54 728.625 Q1549.69 729.041 1547.74 729.921 L1547.74 712.56 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><polyline clip-path=\"url(#clip353)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  947.478,552.936 1552.76,552.936 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip353)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  947.478,390.403 1552.76,390.403 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip353)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  947.478,227.869 1552.76,227.869 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip353)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  947.478,65.3348 1552.76,65.3348 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  947.478,686.448 947.478,47.2441 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  947.478,552.936 966.376,552.936 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  947.478,390.403 966.376,390.403 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  947.478,227.869 966.376,227.869 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  947.478,65.3348 966.376,65.3348 \n",
       "  \"/>\n",
       "<path clip-path=\"url(#clip350)\" d=\"M850.992 553.388 L880.668 553.388 L880.668 557.323 L850.992 557.323 L850.992 553.388 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M891.571 566.281 L899.209 566.281 L899.209 539.916 L890.899 541.582 L890.899 537.323 L899.163 535.656 L903.839 535.656 L903.839 566.281 L911.478 566.281 L911.478 570.216 L891.571 570.216 L891.571 566.281 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M899.534 376.201 Q895.922 376.201 894.094 379.766 Q892.288 383.308 892.288 390.437 Q892.288 397.544 894.094 401.109 Q895.922 404.65 899.534 404.65 Q903.168 404.65 904.973 401.109 Q906.802 397.544 906.802 390.437 Q906.802 383.308 904.973 379.766 Q903.168 376.201 899.534 376.201 M899.534 372.498 Q905.344 372.498 908.399 377.104 Q911.478 381.687 911.478 390.437 Q911.478 399.164 908.399 403.771 Q905.344 408.354 899.534 408.354 Q893.723 408.354 890.645 403.771 Q887.589 399.164 887.589 390.437 Q887.589 381.687 890.645 377.104 Q893.723 372.498 899.534 372.498 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M891.571 241.214 L899.209 241.214 L899.209 214.848 L890.899 216.515 L890.899 212.255 L899.163 210.589 L903.839 210.589 L903.839 241.214 L911.478 241.214 L911.478 245.149 L891.571 245.149 L891.571 241.214 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M895.159 78.6796 L911.478 78.6796 L911.478 82.6148 L889.534 82.6148 L889.534 78.6796 Q892.196 75.925 896.779 71.2954 Q901.385 66.6426 902.566 65.3 Q904.811 62.7769 905.691 61.0408 Q906.594 59.2816 906.594 57.5918 Q906.594 54.8371 904.649 53.101 Q902.728 51.3649 899.626 51.3649 Q897.427 51.3649 894.973 52.1288 Q892.543 52.8927 889.765 54.4436 L889.765 49.7214 Q892.589 48.5872 895.043 48.0085 Q897.497 47.4298 899.534 47.4298 Q904.904 47.4298 908.098 50.1149 Q911.293 52.8001 911.293 57.2908 Q911.293 59.4204 910.483 61.3417 Q909.696 63.2399 907.589 65.8325 Q907.01 66.5037 903.909 69.7213 Q900.807 72.9157 895.159 78.6796 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><circle clip-path=\"url(#clip353)\" cx=\"964.608\" cy=\"65.3348\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"984.299\" cy=\"74.0299\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1003.99\" cy=\"107.304\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1023.68\" cy=\"189.125\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1043.37\" cy=\"296.6\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1063.06\" cy=\"403.389\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1082.75\" cy=\"504.355\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1102.44\" cy=\"592.409\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1122.13\" cy=\"649.003\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1141.82\" cy=\"668.357\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1161.51\" cy=\"668.133\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1181.2\" cy=\"664.117\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1200.89\" cy=\"658.507\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1220.58\" cy=\"642.767\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1240.27\" cy=\"606.259\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1259.96\" cy=\"549.827\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1279.65\" cy=\"484.289\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1299.34\" cy=\"418.586\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1319.03\" cy=\"355.162\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1338.72\" cy=\"294.413\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1358.41\" cy=\"238.941\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1378.1\" cy=\"194.773\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1397.79\" cy=\"167.385\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1417.48\" cy=\"155.963\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1437.17\" cy=\"154.338\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1456.86\" cy=\"156.301\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1476.55\" cy=\"158.766\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1496.24\" cy=\"161.737\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1515.94\" cy=\"167.693\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1535.63\" cy=\"180.385\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"964.608\" cy=\"65.3348\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"984.299\" cy=\"105.162\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1003.99\" cy=\"142.359\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1023.68\" cy=\"189.732\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1043.37\" cy=\"277.468\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1063.06\" cy=\"376.168\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1082.75\" cy=\"473.359\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1102.44\" cy=\"562.613\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1122.13\" cy=\"630.128\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1141.82\" cy=\"661.354\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1161.51\" cy=\"656.227\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1181.2\" cy=\"646.956\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1200.89\" cy=\"641.276\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1220.58\" cy=\"629.821\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1240.27\" cy=\"603.291\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1259.96\" cy=\"559.32\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1279.65\" cy=\"500.183\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1299.34\" cy=\"443.181\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1319.03\" cy=\"389.177\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1338.72\" cy=\"337.476\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1358.41\" cy=\"288.822\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1378.1\" cy=\"245.55\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1397.79\" cy=\"206.791\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1417.48\" cy=\"176.476\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1437.17\" cy=\"165.609\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1456.86\" cy=\"171.455\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1476.55\" cy=\"180.274\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1496.24\" cy=\"186.776\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1515.94\" cy=\"193.965\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip353)\" cx=\"1535.63\" cy=\"211.468\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<path clip-path=\"url(#clip350)\" d=\"\n",
       "M1747.48 686.448 L2352.76 686.448 L2352.76 47.2441 L1747.48 47.2441  Z\n",
       "  \" fill=\"#ffffff\" fill-rule=\"evenodd\" fill-opacity=\"1\"/>\n",
       "<defs>\n",
       "  <clipPath id=\"clip354\">\n",
       "    <rect x=\"1747\" y=\"47\" width=\"606\" height=\"640\"/>\n",
       "  </clipPath>\n",
       "</defs>\n",
       "<polyline clip-path=\"url(#clip354)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  1764.61,686.448 1764.61,47.2441 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip354)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  1954.95,686.448 1954.95,47.2441 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip354)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  2145.29,686.448 2145.29,47.2441 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip354)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  2335.63,686.448 2335.63,47.2441 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  1747.48,686.448 2352.76,686.448 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  1764.61,686.448 1764.61,667.55 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  1954.95,686.448 1954.95,667.55 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  2145.29,686.448 2145.29,667.55 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  2335.63,686.448 2335.63,667.55 \n",
       "  \"/>\n",
       "<path clip-path=\"url(#clip350)\" d=\"M1741.99 715.639 Q1738.38 715.639 1736.55 719.203 Q1734.75 722.745 1734.75 729.875 Q1734.75 736.981 1736.55 740.546 Q1738.38 744.087 1741.99 744.087 Q1745.63 744.087 1747.43 740.546 Q1749.26 736.981 1749.26 729.875 Q1749.26 722.745 1747.43 719.203 Q1745.63 715.639 1741.99 715.639 M1741.99 711.935 Q1747.8 711.935 1750.86 716.541 Q1753.94 721.125 1753.94 729.875 Q1753.94 738.601 1750.86 743.208 Q1747.8 747.791 1741.99 747.791 Q1736.18 747.791 1733.1 743.208 Q1730.05 738.601 1730.05 729.875 Q1730.05 721.125 1733.1 716.541 Q1736.18 711.935 1741.99 711.935 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M1762.15 741.24 L1767.04 741.24 L1767.04 747.12 L1762.15 747.12 L1762.15 741.24 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M1787.22 715.639 Q1783.61 715.639 1781.78 719.203 Q1779.98 722.745 1779.98 729.875 Q1779.98 736.981 1781.78 740.546 Q1783.61 744.087 1787.22 744.087 Q1790.86 744.087 1792.66 740.546 Q1794.49 736.981 1794.49 729.875 Q1794.49 722.745 1792.66 719.203 Q1790.86 715.639 1787.22 715.639 M1787.22 711.935 Q1793.03 711.935 1796.09 716.541 Q1799.17 721.125 1799.17 729.875 Q1799.17 738.601 1796.09 743.208 Q1793.03 747.791 1787.22 747.791 Q1781.41 747.791 1778.34 743.208 Q1775.28 738.601 1775.28 729.875 Q1775.28 721.125 1778.34 716.541 Q1781.41 711.935 1787.22 711.935 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M1932.83 715.639 Q1929.22 715.639 1927.39 719.203 Q1925.58 722.745 1925.58 729.875 Q1925.58 736.981 1927.39 740.546 Q1929.22 744.087 1932.83 744.087 Q1936.46 744.087 1938.27 740.546 Q1940.1 736.981 1940.1 729.875 Q1940.1 722.745 1938.27 719.203 Q1936.46 715.639 1932.83 715.639 M1932.83 711.935 Q1938.64 711.935 1941.7 716.541 Q1944.77 721.125 1944.77 729.875 Q1944.77 738.601 1941.7 743.208 Q1938.64 747.791 1932.83 747.791 Q1927.02 747.791 1923.94 743.208 Q1920.89 738.601 1920.89 729.875 Q1920.89 721.125 1923.94 716.541 Q1927.02 711.935 1932.83 711.935 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M1952.99 741.24 L1957.88 741.24 L1957.88 747.12 L1952.99 747.12 L1952.99 741.24 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M1968.11 712.56 L1986.46 712.56 L1986.46 716.495 L1972.39 716.495 L1972.39 724.967 Q1973.41 724.62 1974.43 724.458 Q1975.44 724.273 1976.46 724.273 Q1982.25 724.273 1985.63 727.444 Q1989.01 730.615 1989.01 736.032 Q1989.01 741.611 1985.54 744.712 Q1982.07 747.791 1975.75 747.791 Q1973.57 747.791 1971.3 747.421 Q1969.06 747.05 1966.65 746.31 L1966.65 741.611 Q1968.73 742.745 1970.95 743.3 Q1973.18 743.856 1975.65 743.856 Q1979.66 743.856 1982 741.75 Q1984.33 739.643 1984.33 736.032 Q1984.33 732.421 1982 730.314 Q1979.66 728.208 1975.65 728.208 Q1973.78 728.208 1971.9 728.625 Q1970.05 729.041 1968.11 729.921 L1968.11 712.56 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M2112.44 743.185 L2120.08 743.185 L2120.08 716.819 L2111.77 718.486 L2111.77 714.227 L2120.03 712.56 L2124.71 712.56 L2124.71 743.185 L2132.35 743.185 L2132.35 747.12 L2112.44 747.12 L2112.44 743.185 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M2141.79 741.24 L2146.68 741.24 L2146.68 747.12 L2141.79 747.12 L2141.79 741.24 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M2166.86 715.639 Q2163.25 715.639 2161.42 719.203 Q2159.62 722.745 2159.62 729.875 Q2159.62 736.981 2161.42 740.546 Q2163.25 744.087 2166.86 744.087 Q2170.49 744.087 2172.3 740.546 Q2174.13 736.981 2174.13 729.875 Q2174.13 722.745 2172.3 719.203 Q2170.49 715.639 2166.86 715.639 M2166.86 711.935 Q2172.67 711.935 2175.73 716.541 Q2178.8 721.125 2178.8 729.875 Q2178.8 738.601 2175.73 743.208 Q2172.67 747.791 2166.86 747.791 Q2161.05 747.791 2157.97 743.208 Q2154.92 738.601 2154.92 729.875 Q2154.92 721.125 2157.97 716.541 Q2161.05 711.935 2166.86 711.935 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M2303.28 743.185 L2310.91 743.185 L2310.91 716.819 L2302.6 718.486 L2302.6 714.227 L2310.87 712.56 L2315.54 712.56 L2315.54 743.185 L2323.18 743.185 L2323.18 747.12 L2303.28 747.12 L2303.28 743.185 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M2332.63 741.24 L2337.51 741.24 L2337.51 747.12 L2332.63 747.12 L2332.63 741.24 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M2347.74 712.56 L2366.1 712.56 L2366.1 716.495 L2352.03 716.495 L2352.03 724.967 Q2353.04 724.62 2354.06 724.458 Q2355.08 724.273 2356.1 724.273 Q2361.89 724.273 2365.27 727.444 Q2368.65 730.615 2368.65 736.032 Q2368.65 741.611 2365.17 744.712 Q2361.7 747.791 2355.38 747.791 Q2353.21 747.791 2350.94 747.421 Q2348.69 747.05 2346.29 746.31 L2346.29 741.611 Q2348.37 742.745 2350.59 743.3 Q2352.81 743.856 2355.29 743.856 Q2359.29 743.856 2361.63 741.75 Q2363.97 739.643 2363.97 736.032 Q2363.97 732.421 2361.63 730.314 Q2359.29 728.208 2355.29 728.208 Q2353.41 728.208 2351.54 728.625 Q2349.69 729.041 2347.74 729.921 L2347.74 712.56 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><polyline clip-path=\"url(#clip354)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  1747.48,550.457 2352.76,550.457 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip354)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  1747.48,388.75 2352.76,388.75 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip354)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  1747.48,227.042 2352.76,227.042 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip354)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  1747.48,65.3348 2352.76,65.3348 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  1747.48,686.448 1747.48,47.2441 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  1747.48,550.457 1766.38,550.457 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  1747.48,388.75 1766.38,388.75 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  1747.48,227.042 1766.38,227.042 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  1747.48,65.3348 1766.38,65.3348 \n",
       "  \"/>\n",
       "<path clip-path=\"url(#clip350)\" d=\"M1650.99 550.909 L1680.67 550.909 L1680.67 554.844 L1650.99 554.844 L1650.99 550.909 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M1691.57 563.802 L1699.21 563.802 L1699.21 537.437 L1690.9 539.103 L1690.9 534.844 L1699.16 533.177 L1703.84 533.177 L1703.84 563.802 L1711.48 563.802 L1711.48 567.737 L1691.57 567.737 L1691.57 563.802 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M1699.53 374.549 Q1695.92 374.549 1694.09 378.113 Q1692.29 381.655 1692.29 388.785 Q1692.29 395.891 1694.09 399.456 Q1695.92 402.997 1699.53 402.997 Q1703.17 402.997 1704.97 399.456 Q1706.8 395.891 1706.8 388.785 Q1706.8 381.655 1704.97 378.113 Q1703.17 374.549 1699.53 374.549 M1699.53 370.845 Q1705.34 370.845 1708.4 375.451 Q1711.48 380.035 1711.48 388.785 Q1711.48 397.511 1708.4 402.118 Q1705.34 406.701 1699.53 406.701 Q1693.72 406.701 1690.64 402.118 Q1687.59 397.511 1687.59 388.785 Q1687.59 380.035 1690.64 375.451 Q1693.72 370.845 1699.53 370.845 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M1691.57 240.387 L1699.21 240.387 L1699.21 214.022 L1690.9 215.688 L1690.9 211.429 L1699.16 209.762 L1703.84 209.762 L1703.84 240.387 L1711.48 240.387 L1711.48 244.322 L1691.57 244.322 L1691.57 240.387 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M1695.16 78.6796 L1711.48 78.6796 L1711.48 82.6148 L1689.53 82.6148 L1689.53 78.6796 Q1692.2 75.925 1696.78 71.2954 Q1701.39 66.6426 1702.57 65.3 Q1704.81 62.7769 1705.69 61.0408 Q1706.59 59.2816 1706.59 57.5918 Q1706.59 54.8371 1704.65 53.101 Q1702.73 51.3649 1699.63 51.3649 Q1697.43 51.3649 1694.97 52.1288 Q1692.54 52.8927 1689.77 54.4436 L1689.77 49.7214 Q1692.59 48.5872 1695.04 48.0085 Q1697.5 47.4298 1699.53 47.4298 Q1704.9 47.4298 1708.1 50.1149 Q1711.29 52.8001 1711.29 57.2908 Q1711.29 59.4204 1710.48 61.3417 Q1709.7 63.2399 1707.59 65.8325 Q1707.01 66.5037 1703.91 69.7213 Q1700.81 72.9157 1695.16 78.6796 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><circle clip-path=\"url(#clip354)\" cx=\"1764.61\" cy=\"65.3348\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"1784.3\" cy=\"73.9857\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"1803.99\" cy=\"107.091\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"1823.68\" cy=\"188.496\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"1843.37\" cy=\"295.424\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"1863.06\" cy=\"401.671\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"1882.75\" cy=\"502.123\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"1902.44\" cy=\"589.73\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"1922.13\" cy=\"646.035\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"1941.82\" cy=\"665.291\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"1961.51\" cy=\"665.068\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"1981.2\" cy=\"661.073\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"2000.89\" cy=\"655.491\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"2020.58\" cy=\"639.831\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"2040.27\" cy=\"603.509\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"2059.96\" cy=\"547.364\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"2079.65\" cy=\"482.159\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"2099.34\" cy=\"416.79\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"2119.03\" cy=\"353.688\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"2138.72\" cy=\"293.249\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"2158.41\" cy=\"238.058\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"2178.1\" cy=\"194.115\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"2197.79\" cy=\"166.866\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"2217.48\" cy=\"155.502\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"2237.17\" cy=\"153.885\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"2256.86\" cy=\"155.839\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"2276.55\" cy=\"158.291\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"2296.24\" cy=\"161.247\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"2315.94\" cy=\"167.173\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"2335.63\" cy=\"179.8\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"1764.61\" cy=\"65.3348\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"1784.3\" cy=\"98.1442\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"1803.99\" cy=\"129.852\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"1823.68\" cy=\"176.291\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"1843.37\" cy=\"278.534\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"1863.06\" cy=\"391.872\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"1882.75\" cy=\"502.675\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"1902.44\" cy=\"597.288\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"1922.13\" cy=\"650.884\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"1941.82\" cy=\"668.357\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"1961.51\" cy=\"661.594\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"1981.2\" cy=\"652.423\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"2000.89\" cy=\"645.871\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"2020.58\" cy=\"634.481\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"2040.27\" cy=\"603.993\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"2059.96\" cy=\"541.858\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"2079.65\" cy=\"472.851\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"2099.34\" cy=\"409.593\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"2119.03\" cy=\"349.774\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"2138.72\" cy=\"293.732\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"2158.41\" cy=\"245.525\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"2178.1\" cy=\"209.6\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"2197.79\" cy=\"182.507\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"2217.48\" cy=\"165.066\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"2237.17\" cy=\"162.252\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"2256.86\" cy=\"166.796\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"2276.55\" cy=\"171.719\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"2296.24\" cy=\"175.52\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"2315.94\" cy=\"182.211\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip354)\" cx=\"2335.63\" cy=\"201.676\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<path clip-path=\"url(#clip350)\" d=\"\n",
       "M147.478 1486.45 L752.756 1486.45 L752.756 847.244 L147.478 847.244  Z\n",
       "  \" fill=\"#ffffff\" fill-rule=\"evenodd\" fill-opacity=\"1\"/>\n",
       "<defs>\n",
       "  <clipPath id=\"clip355\">\n",
       "    <rect x=\"147\" y=\"847\" width=\"606\" height=\"640\"/>\n",
       "  </clipPath>\n",
       "</defs>\n",
       "<polyline clip-path=\"url(#clip355)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  164.608,1486.45 164.608,847.244 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip355)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  354.947,1486.45 354.947,847.244 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip355)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  545.286,1486.45 545.286,847.244 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip355)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  735.625,1486.45 735.625,847.244 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  147.478,1486.45 752.756,1486.45 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  164.608,1486.45 164.608,1467.55 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  354.947,1486.45 354.947,1467.55 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  545.286,1486.45 545.286,1467.55 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  735.625,1486.45 735.625,1467.55 \n",
       "  \"/>\n",
       "<path clip-path=\"url(#clip350)\" d=\"M141.993 1515.64 Q138.382 1515.64 136.553 1519.2 Q134.747 1522.75 134.747 1529.87 Q134.747 1536.98 136.553 1540.55 Q138.382 1544.09 141.993 1544.09 Q145.627 1544.09 147.433 1540.55 Q149.261 1536.98 149.261 1529.87 Q149.261 1522.75 147.433 1519.2 Q145.627 1515.64 141.993 1515.64 M141.993 1511.93 Q147.803 1511.93 150.858 1516.54 Q153.937 1521.12 153.937 1529.87 Q153.937 1538.6 150.858 1543.21 Q147.803 1547.79 141.993 1547.79 Q136.183 1547.79 133.104 1543.21 Q130.048 1538.6 130.048 1529.87 Q130.048 1521.12 133.104 1516.54 Q136.183 1511.93 141.993 1511.93 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M162.155 1541.24 L167.039 1541.24 L167.039 1547.12 L162.155 1547.12 L162.155 1541.24 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M187.224 1515.64 Q183.613 1515.64 181.784 1519.2 Q179.979 1522.75 179.979 1529.87 Q179.979 1536.98 181.784 1540.55 Q183.613 1544.09 187.224 1544.09 Q190.858 1544.09 192.664 1540.55 Q194.493 1536.98 194.493 1529.87 Q194.493 1522.75 192.664 1519.2 Q190.858 1515.64 187.224 1515.64 M187.224 1511.93 Q193.034 1511.93 196.09 1516.54 Q199.168 1521.12 199.168 1529.87 Q199.168 1538.6 196.09 1543.21 Q193.034 1547.79 187.224 1547.79 Q181.414 1547.79 178.335 1543.21 Q175.28 1538.6 175.28 1529.87 Q175.28 1521.12 178.335 1516.54 Q181.414 1511.93 187.224 1511.93 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M332.829 1515.64 Q329.218 1515.64 327.39 1519.2 Q325.584 1522.75 325.584 1529.87 Q325.584 1536.98 327.39 1540.55 Q329.218 1544.09 332.829 1544.09 Q336.464 1544.09 338.269 1540.55 Q340.098 1536.98 340.098 1529.87 Q340.098 1522.75 338.269 1519.2 Q336.464 1515.64 332.829 1515.64 M332.829 1511.93 Q338.64 1511.93 341.695 1516.54 Q344.774 1521.12 344.774 1529.87 Q344.774 1538.6 341.695 1543.21 Q338.64 1547.79 332.829 1547.79 Q327.019 1547.79 323.941 1543.21 Q320.885 1538.6 320.885 1529.87 Q320.885 1521.12 323.941 1516.54 Q327.019 1511.93 332.829 1511.93 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M352.991 1541.24 L357.876 1541.24 L357.876 1547.12 L352.991 1547.12 L352.991 1541.24 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M368.107 1512.56 L386.463 1512.56 L386.463 1516.5 L372.389 1516.5 L372.389 1524.97 Q373.408 1524.62 374.426 1524.46 Q375.445 1524.27 376.464 1524.27 Q382.251 1524.27 385.63 1527.44 Q389.01 1530.62 389.01 1536.03 Q389.01 1541.61 385.538 1544.71 Q382.065 1547.79 375.746 1547.79 Q373.57 1547.79 371.301 1547.42 Q369.056 1547.05 366.649 1546.31 L366.649 1541.61 Q368.732 1542.74 370.954 1543.3 Q373.176 1543.86 375.653 1543.86 Q379.658 1543.86 381.996 1541.75 Q384.334 1539.64 384.334 1536.03 Q384.334 1532.42 381.996 1530.31 Q379.658 1528.21 375.653 1528.21 Q373.778 1528.21 371.903 1528.62 Q370.051 1529.04 368.107 1529.92 L368.107 1512.56 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M512.439 1543.18 L520.078 1543.18 L520.078 1516.82 L511.768 1518.49 L511.768 1514.23 L520.032 1512.56 L524.708 1512.56 L524.708 1543.18 L532.347 1543.18 L532.347 1547.12 L512.439 1547.12 L512.439 1543.18 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M541.791 1541.24 L546.675 1541.24 L546.675 1547.12 L541.791 1547.12 L541.791 1541.24 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M566.86 1515.64 Q563.249 1515.64 561.421 1519.2 Q559.615 1522.75 559.615 1529.87 Q559.615 1536.98 561.421 1540.55 Q563.249 1544.09 566.86 1544.09 Q570.495 1544.09 572.3 1540.55 Q574.129 1536.98 574.129 1529.87 Q574.129 1522.75 572.3 1519.2 Q570.495 1515.64 566.86 1515.64 M566.86 1511.93 Q572.671 1511.93 575.726 1516.54 Q578.805 1521.12 578.805 1529.87 Q578.805 1538.6 575.726 1543.21 Q572.671 1547.79 566.86 1547.79 Q561.05 1547.79 557.972 1543.21 Q554.916 1538.6 554.916 1529.87 Q554.916 1521.12 557.972 1516.54 Q561.05 1511.93 566.86 1511.93 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M703.276 1543.18 L710.915 1543.18 L710.915 1516.82 L702.605 1518.49 L702.605 1514.23 L710.869 1512.56 L715.544 1512.56 L715.544 1543.18 L723.183 1543.18 L723.183 1547.12 L703.276 1547.12 L703.276 1543.18 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M732.628 1541.24 L737.512 1541.24 L737.512 1547.12 L732.628 1547.12 L732.628 1541.24 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M747.743 1512.56 L766.1 1512.56 L766.1 1516.5 L752.026 1516.5 L752.026 1524.97 Q753.044 1524.62 754.063 1524.46 Q755.081 1524.27 756.1 1524.27 Q761.887 1524.27 765.266 1527.44 Q768.646 1530.62 768.646 1536.03 Q768.646 1541.61 765.174 1544.71 Q761.702 1547.79 755.382 1547.79 Q753.206 1547.79 750.938 1547.42 Q748.692 1547.05 746.285 1546.31 L746.285 1541.61 Q748.368 1542.74 750.591 1543.3 Q752.813 1543.86 755.29 1543.86 Q759.294 1543.86 761.632 1541.75 Q763.97 1539.64 763.97 1536.03 Q763.97 1532.42 761.632 1530.31 Q759.294 1528.21 755.29 1528.21 Q753.415 1528.21 751.54 1528.62 Q749.688 1529.04 747.743 1529.92 L747.743 1512.56 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><polyline clip-path=\"url(#clip355)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  147.478,1352.94 752.756,1352.94 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip355)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  147.478,1190.4 752.756,1190.4 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip355)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  147.478,1027.87 752.756,1027.87 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip355)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  147.478,865.335 752.756,865.335 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  147.478,1486.45 147.478,847.244 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  147.478,1352.94 166.376,1352.94 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  147.478,1190.4 166.376,1190.4 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  147.478,1027.87 166.376,1027.87 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  147.478,865.335 166.376,865.335 \n",
       "  \"/>\n",
       "<path clip-path=\"url(#clip350)\" d=\"M50.9921 1353.39 L80.6679 1353.39 L80.6679 1357.32 L50.9921 1357.32 L50.9921 1353.39 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M91.5706 1366.28 L99.2095 1366.28 L99.2095 1339.92 L90.8993 1341.58 L90.8993 1337.32 L99.1632 1335.66 L103.839 1335.66 L103.839 1366.28 L111.478 1366.28 L111.478 1370.22 L91.5706 1370.22 L91.5706 1366.28 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M99.5335 1176.2 Q95.9224 1176.2 94.0937 1179.77 Q92.2882 1183.31 92.2882 1190.44 Q92.2882 1197.54 94.0937 1201.11 Q95.9224 1204.65 99.5335 1204.65 Q103.168 1204.65 104.973 1201.11 Q106.802 1197.54 106.802 1190.44 Q106.802 1183.31 104.973 1179.77 Q103.168 1176.2 99.5335 1176.2 M99.5335 1172.5 Q105.344 1172.5 108.399 1177.1 Q111.478 1181.69 111.478 1190.44 Q111.478 1199.16 108.399 1203.77 Q105.344 1208.35 99.5335 1208.35 Q93.7234 1208.35 90.6447 1203.77 Q87.5892 1199.16 87.5892 1190.44 Q87.5892 1181.69 90.6447 1177.1 Q93.7234 1172.5 99.5335 1172.5 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M91.5706 1041.21 L99.2095 1041.21 L99.2095 1014.85 L90.8993 1016.51 L90.8993 1012.26 L99.1632 1010.59 L103.839 1010.59 L103.839 1041.21 L111.478 1041.21 L111.478 1045.15 L91.5706 1045.15 L91.5706 1041.21 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M95.1586 878.68 L111.478 878.68 L111.478 882.615 L89.5336 882.615 L89.5336 878.68 Q92.1956 875.925 96.7789 871.295 Q101.385 866.643 102.566 865.3 Q104.811 862.777 105.691 861.041 Q106.594 859.282 106.594 857.592 Q106.594 854.837 104.649 853.101 Q102.728 851.365 99.6261 851.365 Q97.4271 851.365 94.9734 852.129 Q92.5428 852.893 89.7651 854.444 L89.7651 849.721 Q92.5891 848.587 95.0428 848.008 Q97.4965 847.43 99.5335 847.43 Q104.904 847.43 108.098 850.115 Q111.293 852.8 111.293 857.291 Q111.293 859.42 110.483 861.342 Q109.696 863.24 107.589 865.832 Q107.01 866.504 103.909 869.721 Q100.807 872.916 95.1586 878.68 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><circle clip-path=\"url(#clip355)\" cx=\"164.608\" cy=\"865.335\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"184.299\" cy=\"874.03\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"203.989\" cy=\"907.304\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"223.679\" cy=\"989.125\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"243.369\" cy=\"1096.6\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"263.06\" cy=\"1203.39\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"282.75\" cy=\"1304.35\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"302.44\" cy=\"1392.41\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"322.13\" cy=\"1449\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"341.821\" cy=\"1468.36\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"361.511\" cy=\"1468.13\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"381.201\" cy=\"1464.12\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"400.891\" cy=\"1458.51\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"420.582\" cy=\"1442.77\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"440.272\" cy=\"1406.26\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"459.962\" cy=\"1349.83\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"479.652\" cy=\"1284.29\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"499.343\" cy=\"1218.59\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"519.033\" cy=\"1155.16\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"538.723\" cy=\"1094.41\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"558.413\" cy=\"1038.94\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"578.103\" cy=\"994.773\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"597.794\" cy=\"967.385\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"617.484\" cy=\"955.963\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"637.174\" cy=\"954.338\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"656.864\" cy=\"956.301\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"676.555\" cy=\"958.766\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"696.245\" cy=\"961.737\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"715.935\" cy=\"967.693\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"735.625\" cy=\"980.385\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"164.608\" cy=\"865.335\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"184.299\" cy=\"896.799\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"203.989\" cy=\"927.439\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"223.679\" cy=\"979.342\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"243.369\" cy=\"1085.28\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"263.06\" cy=\"1198.31\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"282.75\" cy=\"1309.5\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"302.44\" cy=\"1402.57\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"322.13\" cy=\"1452.51\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"341.821\" cy=\"1464.57\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"361.511\" cy=\"1458.92\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"381.201\" cy=\"1452.38\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"400.891\" cy=\"1447.48\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"420.582\" cy=\"1436.15\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"440.272\" cy=\"1404.48\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"459.962\" cy=\"1344.85\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"479.652\" cy=\"1275.17\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"499.343\" cy=\"1209.83\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"519.033\" cy=\"1147.75\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"538.723\" cy=\"1089.26\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"558.413\" cy=\"1038.78\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"578.103\" cy=\"1001.79\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"597.794\" cy=\"975.523\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"617.484\" cy=\"963.32\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"637.174\" cy=\"963.071\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"656.864\" cy=\"967.23\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"676.555\" cy=\"970.933\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"696.245\" cy=\"973.844\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"715.935\" cy=\"979.487\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip355)\" cx=\"735.625\" cy=\"1001.23\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<path clip-path=\"url(#clip350)\" d=\"\n",
       "M947.478 1486.45 L1552.76 1486.45 L1552.76 847.244 L947.478 847.244  Z\n",
       "  \" fill=\"#ffffff\" fill-rule=\"evenodd\" fill-opacity=\"1\"/>\n",
       "<defs>\n",
       "  <clipPath id=\"clip356\">\n",
       "    <rect x=\"947\" y=\"847\" width=\"606\" height=\"640\"/>\n",
       "  </clipPath>\n",
       "</defs>\n",
       "<polyline clip-path=\"url(#clip356)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  964.608,1486.45 964.608,847.244 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip356)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  1154.95,1486.45 1154.95,847.244 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip356)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  1345.29,1486.45 1345.29,847.244 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip356)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  1535.63,1486.45 1535.63,847.244 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  947.478,1486.45 1552.76,1486.45 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  964.608,1486.45 964.608,1467.55 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  1154.95,1486.45 1154.95,1467.55 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  1345.29,1486.45 1345.29,1467.55 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  1535.63,1486.45 1535.63,1467.55 \n",
       "  \"/>\n",
       "<path clip-path=\"url(#clip350)\" d=\"M941.993 1515.64 Q938.382 1515.64 936.553 1519.2 Q934.747 1522.75 934.747 1529.87 Q934.747 1536.98 936.553 1540.55 Q938.382 1544.09 941.993 1544.09 Q945.627 1544.09 947.433 1540.55 Q949.261 1536.98 949.261 1529.87 Q949.261 1522.75 947.433 1519.2 Q945.627 1515.64 941.993 1515.64 M941.993 1511.93 Q947.803 1511.93 950.858 1516.54 Q953.937 1521.12 953.937 1529.87 Q953.937 1538.6 950.858 1543.21 Q947.803 1547.79 941.993 1547.79 Q936.183 1547.79 933.104 1543.21 Q930.048 1538.6 930.048 1529.87 Q930.048 1521.12 933.104 1516.54 Q936.183 1511.93 941.993 1511.93 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M962.155 1541.24 L967.039 1541.24 L967.039 1547.12 L962.155 1547.12 L962.155 1541.24 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M987.224 1515.64 Q983.613 1515.64 981.784 1519.2 Q979.979 1522.75 979.979 1529.87 Q979.979 1536.98 981.784 1540.55 Q983.613 1544.09 987.224 1544.09 Q990.858 1544.09 992.664 1540.55 Q994.493 1536.98 994.493 1529.87 Q994.493 1522.75 992.664 1519.2 Q990.858 1515.64 987.224 1515.64 M987.224 1511.93 Q993.034 1511.93 996.09 1516.54 Q999.168 1521.12 999.168 1529.87 Q999.168 1538.6 996.09 1543.21 Q993.034 1547.79 987.224 1547.79 Q981.414 1547.79 978.335 1543.21 Q975.28 1538.6 975.28 1529.87 Q975.28 1521.12 978.335 1516.54 Q981.414 1511.93 987.224 1511.93 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M1132.83 1515.64 Q1129.22 1515.64 1127.39 1519.2 Q1125.58 1522.75 1125.58 1529.87 Q1125.58 1536.98 1127.39 1540.55 Q1129.22 1544.09 1132.83 1544.09 Q1136.46 1544.09 1138.27 1540.55 Q1140.1 1536.98 1140.1 1529.87 Q1140.1 1522.75 1138.27 1519.2 Q1136.46 1515.64 1132.83 1515.64 M1132.83 1511.93 Q1138.64 1511.93 1141.7 1516.54 Q1144.77 1521.12 1144.77 1529.87 Q1144.77 1538.6 1141.7 1543.21 Q1138.64 1547.79 1132.83 1547.79 Q1127.02 1547.79 1123.94 1543.21 Q1120.89 1538.6 1120.89 1529.87 Q1120.89 1521.12 1123.94 1516.54 Q1127.02 1511.93 1132.83 1511.93 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M1152.99 1541.24 L1157.88 1541.24 L1157.88 1547.12 L1152.99 1547.12 L1152.99 1541.24 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M1168.11 1512.56 L1186.46 1512.56 L1186.46 1516.5 L1172.39 1516.5 L1172.39 1524.97 Q1173.41 1524.62 1174.43 1524.46 Q1175.44 1524.27 1176.46 1524.27 Q1182.25 1524.27 1185.63 1527.44 Q1189.01 1530.62 1189.01 1536.03 Q1189.01 1541.61 1185.54 1544.71 Q1182.07 1547.79 1175.75 1547.79 Q1173.57 1547.79 1171.3 1547.42 Q1169.06 1547.05 1166.65 1546.31 L1166.65 1541.61 Q1168.73 1542.74 1170.95 1543.3 Q1173.18 1543.86 1175.65 1543.86 Q1179.66 1543.86 1182 1541.75 Q1184.33 1539.64 1184.33 1536.03 Q1184.33 1532.42 1182 1530.31 Q1179.66 1528.21 1175.65 1528.21 Q1173.78 1528.21 1171.9 1528.62 Q1170.05 1529.04 1168.11 1529.92 L1168.11 1512.56 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M1312.44 1543.18 L1320.08 1543.18 L1320.08 1516.82 L1311.77 1518.49 L1311.77 1514.23 L1320.03 1512.56 L1324.71 1512.56 L1324.71 1543.18 L1332.35 1543.18 L1332.35 1547.12 L1312.44 1547.12 L1312.44 1543.18 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M1341.79 1541.24 L1346.68 1541.24 L1346.68 1547.12 L1341.79 1547.12 L1341.79 1541.24 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M1366.86 1515.64 Q1363.25 1515.64 1361.42 1519.2 Q1359.62 1522.75 1359.62 1529.87 Q1359.62 1536.98 1361.42 1540.55 Q1363.25 1544.09 1366.86 1544.09 Q1370.49 1544.09 1372.3 1540.55 Q1374.13 1536.98 1374.13 1529.87 Q1374.13 1522.75 1372.3 1519.2 Q1370.49 1515.64 1366.86 1515.64 M1366.86 1511.93 Q1372.67 1511.93 1375.73 1516.54 Q1378.8 1521.12 1378.8 1529.87 Q1378.8 1538.6 1375.73 1543.21 Q1372.67 1547.79 1366.86 1547.79 Q1361.05 1547.79 1357.97 1543.21 Q1354.92 1538.6 1354.92 1529.87 Q1354.92 1521.12 1357.97 1516.54 Q1361.05 1511.93 1366.86 1511.93 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M1503.28 1543.18 L1510.91 1543.18 L1510.91 1516.82 L1502.6 1518.49 L1502.6 1514.23 L1510.87 1512.56 L1515.54 1512.56 L1515.54 1543.18 L1523.18 1543.18 L1523.18 1547.12 L1503.28 1547.12 L1503.28 1543.18 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M1532.63 1541.24 L1537.51 1541.24 L1537.51 1547.12 L1532.63 1547.12 L1532.63 1541.24 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M1547.74 1512.56 L1566.1 1512.56 L1566.1 1516.5 L1552.03 1516.5 L1552.03 1524.97 Q1553.04 1524.62 1554.06 1524.46 Q1555.08 1524.27 1556.1 1524.27 Q1561.89 1524.27 1565.27 1527.44 Q1568.65 1530.62 1568.65 1536.03 Q1568.65 1541.61 1565.17 1544.71 Q1561.7 1547.79 1555.38 1547.79 Q1553.21 1547.79 1550.94 1547.42 Q1548.69 1547.05 1546.29 1546.31 L1546.29 1541.61 Q1548.37 1542.74 1550.59 1543.3 Q1552.81 1543.86 1555.29 1543.86 Q1559.29 1543.86 1561.63 1541.75 Q1563.97 1539.64 1563.97 1536.03 Q1563.97 1532.42 1561.63 1530.31 Q1559.29 1528.21 1555.29 1528.21 Q1553.41 1528.21 1551.54 1528.62 Q1549.69 1529.04 1547.74 1529.92 L1547.74 1512.56 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><polyline clip-path=\"url(#clip356)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  947.478,1352.94 1552.76,1352.94 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip356)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  947.478,1190.4 1552.76,1190.4 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip356)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  947.478,1027.87 1552.76,1027.87 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip356)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  947.478,865.335 1552.76,865.335 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  947.478,1486.45 947.478,847.244 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  947.478,1352.94 966.376,1352.94 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  947.478,1190.4 966.376,1190.4 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  947.478,1027.87 966.376,1027.87 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  947.478,865.335 966.376,865.335 \n",
       "  \"/>\n",
       "<path clip-path=\"url(#clip350)\" d=\"M850.992 1353.39 L880.668 1353.39 L880.668 1357.32 L850.992 1357.32 L850.992 1353.39 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M891.571 1366.28 L899.209 1366.28 L899.209 1339.92 L890.899 1341.58 L890.899 1337.32 L899.163 1335.66 L903.839 1335.66 L903.839 1366.28 L911.478 1366.28 L911.478 1370.22 L891.571 1370.22 L891.571 1366.28 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M899.534 1176.2 Q895.922 1176.2 894.094 1179.77 Q892.288 1183.31 892.288 1190.44 Q892.288 1197.54 894.094 1201.11 Q895.922 1204.65 899.534 1204.65 Q903.168 1204.65 904.973 1201.11 Q906.802 1197.54 906.802 1190.44 Q906.802 1183.31 904.973 1179.77 Q903.168 1176.2 899.534 1176.2 M899.534 1172.5 Q905.344 1172.5 908.399 1177.1 Q911.478 1181.69 911.478 1190.44 Q911.478 1199.16 908.399 1203.77 Q905.344 1208.35 899.534 1208.35 Q893.723 1208.35 890.645 1203.77 Q887.589 1199.16 887.589 1190.44 Q887.589 1181.69 890.645 1177.1 Q893.723 1172.5 899.534 1172.5 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M891.571 1041.21 L899.209 1041.21 L899.209 1014.85 L890.899 1016.51 L890.899 1012.26 L899.163 1010.59 L903.839 1010.59 L903.839 1041.21 L911.478 1041.21 L911.478 1045.15 L891.571 1045.15 L891.571 1041.21 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M895.159 878.68 L911.478 878.68 L911.478 882.615 L889.534 882.615 L889.534 878.68 Q892.196 875.925 896.779 871.295 Q901.385 866.643 902.566 865.3 Q904.811 862.777 905.691 861.041 Q906.594 859.282 906.594 857.592 Q906.594 854.837 904.649 853.101 Q902.728 851.365 899.626 851.365 Q897.427 851.365 894.973 852.129 Q892.543 852.893 889.765 854.444 L889.765 849.721 Q892.589 848.587 895.043 848.008 Q897.497 847.43 899.534 847.43 Q904.904 847.43 908.098 850.115 Q911.293 852.8 911.293 857.291 Q911.293 859.42 910.483 861.342 Q909.696 863.24 907.589 865.832 Q907.01 866.504 903.909 869.721 Q900.807 872.916 895.159 878.68 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><circle clip-path=\"url(#clip356)\" cx=\"964.608\" cy=\"865.335\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"984.299\" cy=\"874.03\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1003.99\" cy=\"907.304\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1023.68\" cy=\"989.125\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1043.37\" cy=\"1096.6\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1063.06\" cy=\"1203.39\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1082.75\" cy=\"1304.35\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1102.44\" cy=\"1392.41\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1122.13\" cy=\"1449\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1141.82\" cy=\"1468.36\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1161.51\" cy=\"1468.13\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1181.2\" cy=\"1464.12\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1200.89\" cy=\"1458.51\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1220.58\" cy=\"1442.77\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1240.27\" cy=\"1406.26\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1259.96\" cy=\"1349.83\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1279.65\" cy=\"1284.29\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1299.34\" cy=\"1218.59\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1319.03\" cy=\"1155.16\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1338.72\" cy=\"1094.41\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1358.41\" cy=\"1038.94\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1378.1\" cy=\"994.773\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1397.79\" cy=\"967.385\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1417.48\" cy=\"955.963\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1437.17\" cy=\"954.338\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1456.86\" cy=\"956.301\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1476.55\" cy=\"958.766\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1496.24\" cy=\"961.737\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1515.94\" cy=\"967.693\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1535.63\" cy=\"980.385\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"964.608\" cy=\"865.335\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"984.299\" cy=\"894.567\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1003.99\" cy=\"923.83\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1023.68\" cy=\"982.563\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1043.37\" cy=\"1087.45\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1063.06\" cy=\"1198.11\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1082.75\" cy=\"1307.33\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1102.44\" cy=\"1401.07\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1122.13\" cy=\"1450.23\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1141.82\" cy=\"1461.23\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1161.51\" cy=\"1457.8\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1181.2\" cy=\"1453.26\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1200.89\" cy=\"1449.73\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1220.58\" cy=\"1439.36\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1240.27\" cy=\"1406.98\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1259.96\" cy=\"1352.55\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1279.65\" cy=\"1285.02\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1299.34\" cy=\"1219.41\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1319.03\" cy=\"1156.7\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1338.72\" cy=\"1096.84\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1358.41\" cy=\"1042.93\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1378.1\" cy=\"1001.68\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1397.79\" cy=\"974.281\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1417.48\" cy=\"962.146\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1437.17\" cy=\"961.701\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1456.86\" cy=\"965.198\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1476.55\" cy=\"968.554\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1496.24\" cy=\"971.143\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1515.94\" cy=\"975.366\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip356)\" cx=\"1535.63\" cy=\"989.295\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<path clip-path=\"url(#clip350)\" d=\"\n",
       "M1747.48 1486.45 L2352.76 1486.45 L2352.76 847.244 L1747.48 847.244  Z\n",
       "  \" fill=\"#ffffff\" fill-rule=\"evenodd\" fill-opacity=\"1\"/>\n",
       "<defs>\n",
       "  <clipPath id=\"clip357\">\n",
       "    <rect x=\"1747\" y=\"847\" width=\"606\" height=\"640\"/>\n",
       "  </clipPath>\n",
       "</defs>\n",
       "<polyline clip-path=\"url(#clip357)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  1764.61,1486.45 1764.61,847.244 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip357)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  1954.95,1486.45 1954.95,847.244 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip357)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  2145.29,1486.45 2145.29,847.244 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip357)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  2335.63,1486.45 2335.63,847.244 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  1747.48,1486.45 2352.76,1486.45 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  1764.61,1486.45 1764.61,1467.55 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  1954.95,1486.45 1954.95,1467.55 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  2145.29,1486.45 2145.29,1467.55 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  2335.63,1486.45 2335.63,1467.55 \n",
       "  \"/>\n",
       "<path clip-path=\"url(#clip350)\" d=\"M1741.99 1515.64 Q1738.38 1515.64 1736.55 1519.2 Q1734.75 1522.75 1734.75 1529.87 Q1734.75 1536.98 1736.55 1540.55 Q1738.38 1544.09 1741.99 1544.09 Q1745.63 1544.09 1747.43 1540.55 Q1749.26 1536.98 1749.26 1529.87 Q1749.26 1522.75 1747.43 1519.2 Q1745.63 1515.64 1741.99 1515.64 M1741.99 1511.93 Q1747.8 1511.93 1750.86 1516.54 Q1753.94 1521.12 1753.94 1529.87 Q1753.94 1538.6 1750.86 1543.21 Q1747.8 1547.79 1741.99 1547.79 Q1736.18 1547.79 1733.1 1543.21 Q1730.05 1538.6 1730.05 1529.87 Q1730.05 1521.12 1733.1 1516.54 Q1736.18 1511.93 1741.99 1511.93 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M1762.15 1541.24 L1767.04 1541.24 L1767.04 1547.12 L1762.15 1547.12 L1762.15 1541.24 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M1787.22 1515.64 Q1783.61 1515.64 1781.78 1519.2 Q1779.98 1522.75 1779.98 1529.87 Q1779.98 1536.98 1781.78 1540.55 Q1783.61 1544.09 1787.22 1544.09 Q1790.86 1544.09 1792.66 1540.55 Q1794.49 1536.98 1794.49 1529.87 Q1794.49 1522.75 1792.66 1519.2 Q1790.86 1515.64 1787.22 1515.64 M1787.22 1511.93 Q1793.03 1511.93 1796.09 1516.54 Q1799.17 1521.12 1799.17 1529.87 Q1799.17 1538.6 1796.09 1543.21 Q1793.03 1547.79 1787.22 1547.79 Q1781.41 1547.79 1778.34 1543.21 Q1775.28 1538.6 1775.28 1529.87 Q1775.28 1521.12 1778.34 1516.54 Q1781.41 1511.93 1787.22 1511.93 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M1932.83 1515.64 Q1929.22 1515.64 1927.39 1519.2 Q1925.58 1522.75 1925.58 1529.87 Q1925.58 1536.98 1927.39 1540.55 Q1929.22 1544.09 1932.83 1544.09 Q1936.46 1544.09 1938.27 1540.55 Q1940.1 1536.98 1940.1 1529.87 Q1940.1 1522.75 1938.27 1519.2 Q1936.46 1515.64 1932.83 1515.64 M1932.83 1511.93 Q1938.64 1511.93 1941.7 1516.54 Q1944.77 1521.12 1944.77 1529.87 Q1944.77 1538.6 1941.7 1543.21 Q1938.64 1547.79 1932.83 1547.79 Q1927.02 1547.79 1923.94 1543.21 Q1920.89 1538.6 1920.89 1529.87 Q1920.89 1521.12 1923.94 1516.54 Q1927.02 1511.93 1932.83 1511.93 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M1952.99 1541.24 L1957.88 1541.24 L1957.88 1547.12 L1952.99 1547.12 L1952.99 1541.24 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M1968.11 1512.56 L1986.46 1512.56 L1986.46 1516.5 L1972.39 1516.5 L1972.39 1524.97 Q1973.41 1524.62 1974.43 1524.46 Q1975.44 1524.27 1976.46 1524.27 Q1982.25 1524.27 1985.63 1527.44 Q1989.01 1530.62 1989.01 1536.03 Q1989.01 1541.61 1985.54 1544.71 Q1982.07 1547.79 1975.75 1547.79 Q1973.57 1547.79 1971.3 1547.42 Q1969.06 1547.05 1966.65 1546.31 L1966.65 1541.61 Q1968.73 1542.74 1970.95 1543.3 Q1973.18 1543.86 1975.65 1543.86 Q1979.66 1543.86 1982 1541.75 Q1984.33 1539.64 1984.33 1536.03 Q1984.33 1532.42 1982 1530.31 Q1979.66 1528.21 1975.65 1528.21 Q1973.78 1528.21 1971.9 1528.62 Q1970.05 1529.04 1968.11 1529.92 L1968.11 1512.56 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M2112.44 1543.18 L2120.08 1543.18 L2120.08 1516.82 L2111.77 1518.49 L2111.77 1514.23 L2120.03 1512.56 L2124.71 1512.56 L2124.71 1543.18 L2132.35 1543.18 L2132.35 1547.12 L2112.44 1547.12 L2112.44 1543.18 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M2141.79 1541.24 L2146.68 1541.24 L2146.68 1547.12 L2141.79 1547.12 L2141.79 1541.24 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M2166.86 1515.64 Q2163.25 1515.64 2161.42 1519.2 Q2159.62 1522.75 2159.62 1529.87 Q2159.62 1536.98 2161.42 1540.55 Q2163.25 1544.09 2166.86 1544.09 Q2170.49 1544.09 2172.3 1540.55 Q2174.13 1536.98 2174.13 1529.87 Q2174.13 1522.75 2172.3 1519.2 Q2170.49 1515.64 2166.86 1515.64 M2166.86 1511.93 Q2172.67 1511.93 2175.73 1516.54 Q2178.8 1521.12 2178.8 1529.87 Q2178.8 1538.6 2175.73 1543.21 Q2172.67 1547.79 2166.86 1547.79 Q2161.05 1547.79 2157.97 1543.21 Q2154.92 1538.6 2154.92 1529.87 Q2154.92 1521.12 2157.97 1516.54 Q2161.05 1511.93 2166.86 1511.93 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M2303.28 1543.18 L2310.91 1543.18 L2310.91 1516.82 L2302.6 1518.49 L2302.6 1514.23 L2310.87 1512.56 L2315.54 1512.56 L2315.54 1543.18 L2323.18 1543.18 L2323.18 1547.12 L2303.28 1547.12 L2303.28 1543.18 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M2332.63 1541.24 L2337.51 1541.24 L2337.51 1547.12 L2332.63 1547.12 L2332.63 1541.24 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M2347.74 1512.56 L2366.1 1512.56 L2366.1 1516.5 L2352.03 1516.5 L2352.03 1524.97 Q2353.04 1524.62 2354.06 1524.46 Q2355.08 1524.27 2356.1 1524.27 Q2361.89 1524.27 2365.27 1527.44 Q2368.65 1530.62 2368.65 1536.03 Q2368.65 1541.61 2365.17 1544.71 Q2361.7 1547.79 2355.38 1547.79 Q2353.21 1547.79 2350.94 1547.42 Q2348.69 1547.05 2346.29 1546.31 L2346.29 1541.61 Q2348.37 1542.74 2350.59 1543.3 Q2352.81 1543.86 2355.29 1543.86 Q2359.29 1543.86 2361.63 1541.75 Q2363.97 1539.64 2363.97 1536.03 Q2363.97 1532.42 2361.63 1530.31 Q2359.29 1528.21 2355.29 1528.21 Q2353.41 1528.21 2351.54 1528.62 Q2349.69 1529.04 2347.74 1529.92 L2347.74 1512.56 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><polyline clip-path=\"url(#clip357)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  1747.48,1352.94 2352.76,1352.94 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip357)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  1747.48,1190.4 2352.76,1190.4 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip357)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  1747.48,1027.87 2352.76,1027.87 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip357)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none\" points=\"\n",
       "  1747.48,865.335 2352.76,865.335 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  1747.48,1486.45 1747.48,847.244 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  1747.48,1352.94 1766.38,1352.94 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  1747.48,1190.4 1766.38,1190.4 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  1747.48,1027.87 1766.38,1027.87 \n",
       "  \"/>\n",
       "<polyline clip-path=\"url(#clip350)\" style=\"stroke:#000000; stroke-linecap:butt; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none\" points=\"\n",
       "  1747.48,865.335 1766.38,865.335 \n",
       "  \"/>\n",
       "<path clip-path=\"url(#clip350)\" d=\"M1650.99 1353.39 L1680.67 1353.39 L1680.67 1357.32 L1650.99 1357.32 L1650.99 1353.39 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M1691.57 1366.28 L1699.21 1366.28 L1699.21 1339.92 L1690.9 1341.58 L1690.9 1337.32 L1699.16 1335.66 L1703.84 1335.66 L1703.84 1366.28 L1711.48 1366.28 L1711.48 1370.22 L1691.57 1370.22 L1691.57 1366.28 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M1699.53 1176.2 Q1695.92 1176.2 1694.09 1179.77 Q1692.29 1183.31 1692.29 1190.44 Q1692.29 1197.54 1694.09 1201.11 Q1695.92 1204.65 1699.53 1204.65 Q1703.17 1204.65 1704.97 1201.11 Q1706.8 1197.54 1706.8 1190.44 Q1706.8 1183.31 1704.97 1179.77 Q1703.17 1176.2 1699.53 1176.2 M1699.53 1172.5 Q1705.34 1172.5 1708.4 1177.1 Q1711.48 1181.69 1711.48 1190.44 Q1711.48 1199.16 1708.4 1203.77 Q1705.34 1208.35 1699.53 1208.35 Q1693.72 1208.35 1690.64 1203.77 Q1687.59 1199.16 1687.59 1190.44 Q1687.59 1181.69 1690.64 1177.1 Q1693.72 1172.5 1699.53 1172.5 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M1691.57 1041.21 L1699.21 1041.21 L1699.21 1014.85 L1690.9 1016.51 L1690.9 1012.26 L1699.16 1010.59 L1703.84 1010.59 L1703.84 1041.21 L1711.48 1041.21 L1711.48 1045.15 L1691.57 1045.15 L1691.57 1041.21 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><path clip-path=\"url(#clip350)\" d=\"M1695.16 878.68 L1711.48 878.68 L1711.48 882.615 L1689.53 882.615 L1689.53 878.68 Q1692.2 875.925 1696.78 871.295 Q1701.39 866.643 1702.57 865.3 Q1704.81 862.777 1705.69 861.041 Q1706.59 859.282 1706.59 857.592 Q1706.59 854.837 1704.65 853.101 Q1702.73 851.365 1699.63 851.365 Q1697.43 851.365 1694.97 852.129 Q1692.54 852.893 1689.77 854.444 L1689.77 849.721 Q1692.59 848.587 1695.04 848.008 Q1697.5 847.43 1699.53 847.43 Q1704.9 847.43 1708.1 850.115 Q1711.29 852.8 1711.29 857.291 Q1711.29 859.42 1710.48 861.342 Q1709.7 863.24 1707.59 865.832 Q1707.01 866.504 1703.91 869.721 Q1700.81 872.916 1695.16 878.68 Z\" fill=\"#000000\" fill-rule=\"evenodd\" fill-opacity=\"1\" /><circle clip-path=\"url(#clip357)\" cx=\"1764.61\" cy=\"865.335\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"1784.3\" cy=\"874.03\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"1803.99\" cy=\"907.304\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"1823.68\" cy=\"989.125\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"1843.37\" cy=\"1096.6\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"1863.06\" cy=\"1203.39\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"1882.75\" cy=\"1304.35\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"1902.44\" cy=\"1392.41\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"1922.13\" cy=\"1449\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"1941.82\" cy=\"1468.36\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"1961.51\" cy=\"1468.13\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"1981.2\" cy=\"1464.12\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"2000.89\" cy=\"1458.51\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"2020.58\" cy=\"1442.77\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"2040.27\" cy=\"1406.26\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"2059.96\" cy=\"1349.83\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"2079.65\" cy=\"1284.29\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"2099.34\" cy=\"1218.59\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"2119.03\" cy=\"1155.16\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"2138.72\" cy=\"1094.41\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"2158.41\" cy=\"1038.94\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"2178.1\" cy=\"994.773\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"2197.79\" cy=\"967.385\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"2217.48\" cy=\"955.963\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"2237.17\" cy=\"954.338\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"2256.86\" cy=\"956.301\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"2276.55\" cy=\"958.766\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"2296.24\" cy=\"961.737\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"2315.94\" cy=\"967.693\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"2335.63\" cy=\"980.385\" r=\"14\" fill=\"#009af9\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"1764.61\" cy=\"865.335\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"1784.3\" cy=\"891.153\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"1803.99\" cy=\"919.346\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"1823.68\" cy=\"986.225\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"1843.37\" cy=\"1090.81\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"1863.06\" cy=\"1198.86\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"1882.75\" cy=\"1306.18\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"1902.44\" cy=\"1400.29\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"1922.13\" cy=\"1450.18\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"1941.82\" cy=\"1460.92\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"1961.51\" cy=\"1459.26\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"1981.2\" cy=\"1455.97\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"2000.89\" cy=\"1452.69\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"2020.58\" cy=\"1439.1\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"2040.27\" cy=\"1406.36\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"2059.96\" cy=\"1351.98\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"2079.65\" cy=\"1285.97\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"2099.34\" cy=\"1220.5\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"2119.03\" cy=\"1157.14\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"2138.72\" cy=\"1096\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"2158.41\" cy=\"1039.89\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"2178.1\" cy=\"995.86\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"2197.79\" cy=\"969.197\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"2217.48\" cy=\"959.946\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"2237.17\" cy=\"960.428\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"2256.86\" cy=\"963.777\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"2276.55\" cy=\"966.821\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"2296.24\" cy=\"969.286\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"2315.94\" cy=\"973.557\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "<circle clip-path=\"url(#clip357)\" cx=\"2335.63\" cy=\"988.286\" r=\"14\" fill=\"#e26f46\" fill-rule=\"evenodd\" fill-opacity=\"1\" stroke=\"#000000\" stroke-opacity=\"1\" stroke-width=\"3.2\"/>\n",
       "</svg>\n"
      ]
     },
     "execution_count": 7,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "# using interactive widget\n",
    "plot(training_plots...; legend=false)"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "thermal-priest",
   "metadata": {},
   "source": [
    "And true enough, we were able to fit the parameters of the neural network (can we extract true A from this?)."
   ]
  },
  {
   "cell_type": "markdown",
   "id": "normal-experiment",
   "metadata": {},
   "source": [
    "## Augmented Neural ODE\n",
    "Not every function can be represented by an ODE; specifically, some\n",
    "\n",
    "$$u(t) : \\mathbb{R} \\rightarrow \\mathbb{R}^n$$\n",
    "\n",
    "would be unable to be multivariate unless cyclic.\n",
    "\n",
    "This is because the *flow* of the ODE is unique at every $t$; for the above mapping to have at least *two directions of flow* for a given point $u_i$, there would have to be at least *two solutions* in phase space to\n",
    "\n",
    "$$u^\\prime = f(u, p, t),$$\n",
    "\n",
    "using the convention $u(0) = u_i$, which cannot happen with a monotonic map.\n",
    "\n",
    "We can rectify this by introducing additional degrees of freedom, to ensure that the ODE does not overlap. This is the so-called *augmented neural ODE*. \n",
    "\n",
    "This can be built using the following prescription:\n",
    "- add a fake state to the ODE which is 0 everywhere\n",
    "- allow this extra dimension to *bump* around to let the function become a [universal approximator](https://en.wikipedia.org/wiki/Universal_approximation_theorem)\n",
    "\n",
    "In Julia, this is:\n",
    "```julia\n",
    "dudt = Chain(...)\n",
    "p, re = Flux.destructure(dudt)\n",
    "\n",
    "dudt_(u, p, t) = re(p)(u)\n",
    "prob = ODEProblem(dudt_, [u0, f0], tspan, p)\n",
    "\n",
    "augmented_data = vcat(\n",
    "    ode_data,\n",
    "    zeros(\n",
    "        1,\n",
    "        size(ode_data, 2)\n",
    "    )\n",
    ")\n",
    "```"
   ]
  }
 ],
 "metadata": {
  "@webio": {
   "lastCommId": null,
   "lastKernelId": null
  },
  "kernelspec": {
   "display_name": "Julia 1.6.2",
   "language": "julia",
   "name": "julia-1.6"
  },
  "language_info": {
   "file_extension": ".jl",
   "mimetype": "application/julia",
   "name": "julia",
   "version": "1.6.2"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 5
}
